""" Cisco_IOS_XR_ncs6k_acl_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ncs6k\-acl package operational data.

This module contains definitions
for the following management objects\:
  access\-list\-hardware\: Root class of accesslist hardware

Copyright (c) 2013\-2017 by Cisco Systems, Inc.
All rights reserved.

"""
from collections import OrderedDict

from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class SseGrant(Enum):
    """
    SseGrant (Enum Class)

    ACL grant

    .. data:: permit = 1

    	Grant permit

    .. data:: deny = 2

    	Grant deny

    """

    permit = Enum.YLeaf(1, "permit")

    deny = Enum.YLeaf(2, "deny")


class SsePfilterAddr(Enum):
    """
    SsePfilterAddr (Enum Class)

    Address types

    .. data:: ipv4 = 0

    	IPv4

    .. data:: ipv6 = 1

    	IPv6

    """

    ipv4 = Enum.YLeaf(0, "ipv4")

    ipv6 = Enum.YLeaf(1, "ipv6")



class AccessListHardware(Entity):
    """
    Root class of accesslist hardware
    
    .. attribute:: nodes
    
    	Accesslist nodes
    	**type**\:  :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes>`
    
    

    """

    _prefix = 'ncs6k-acl-oper'
    _revision = '2017-05-01'

    def __init__(self):
        super(AccessListHardware, self).__init__()
        self._top_entity = None

        self.yang_name = "access-list-hardware"
        self.yang_parent_name = "Cisco-IOS-XR-ncs6k-acl-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("nodes", ("nodes", AccessListHardware.Nodes))])
        self._leafs = OrderedDict()

        self.nodes = AccessListHardware.Nodes()
        self.nodes.parent = self
        self._children_name_map["nodes"] = "nodes"
        self._segment_path = lambda: "Cisco-IOS-XR-ncs6k-acl-oper:access-list-hardware"

    def __setattr__(self, name, value):
        self._perform_setattr(AccessListHardware, [], name, value)


    class Nodes(Entity):
        """
        Accesslist nodes
        
        .. attribute:: node
        
        	Accesslist node
        	**type**\: list of  		 :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node>`
        
        

        """

        _prefix = 'ncs6k-acl-oper'
        _revision = '2017-05-01'

        def __init__(self):
            super(AccessListHardware.Nodes, self).__init__()

            self.yang_name = "nodes"
            self.yang_parent_name = "access-list-hardware"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("node", ("node", AccessListHardware.Nodes.Node))])
            self._leafs = OrderedDict()

            self.node = YList(self)
            self._segment_path = lambda: "nodes"
            self._absolute_path = lambda: "Cisco-IOS-XR-ncs6k-acl-oper:access-list-hardware/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(AccessListHardware.Nodes, [], name, value)


        class Node(Entity):
            """
            Accesslist node
            
            .. attribute:: node_name  (key)
            
            	Node name
            	**type**\: str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: egress
            
            	Accesslist direction egress
            	**type**\:  :py:class:`Egress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress>`
            
            .. attribute:: ingress
            
            	Accesslist direction ingress
            	**type**\:  :py:class:`Ingress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress>`
            
            

            """

            _prefix = 'ncs6k-acl-oper'
            _revision = '2017-05-01'

            def __init__(self):
                super(AccessListHardware.Nodes.Node, self).__init__()

                self.yang_name = "node"
                self.yang_parent_name = "nodes"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['node_name']
                self._child_classes = OrderedDict([("egress", ("egress", AccessListHardware.Nodes.Node.Egress)), ("ingress", ("ingress", AccessListHardware.Nodes.Node.Ingress))])
                self._leafs = OrderedDict([
                    ('node_name', YLeaf(YType.str, 'node-name')),
                ])
                self.node_name = None

                self.egress = AccessListHardware.Nodes.Node.Egress()
                self.egress.parent = self
                self._children_name_map["egress"] = "egress"

                self.ingress = AccessListHardware.Nodes.Node.Ingress()
                self.ingress.parent = self
                self._children_name_map["ingress"] = "ingress"
                self._segment_path = lambda: "node" + "[node-name='" + str(self.node_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ncs6k-acl-oper:access-list-hardware/nodes/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(AccessListHardware.Nodes.Node, ['node_name'], name, value)


            class Egress(Entity):
                """
                Accesslist direction egress
                
                .. attribute:: ipv4
                
                	Accesslist version IPv4
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4>`
                
                .. attribute:: ipv6
                
                	Accesslist version IPv6
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6>`
                
                

                """

                _prefix = 'ncs6k-acl-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(AccessListHardware.Nodes.Node.Egress, self).__init__()

                    self.yang_name = "egress"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4", ("ipv4", AccessListHardware.Nodes.Node.Egress.Ipv4)), ("ipv6", ("ipv6", AccessListHardware.Nodes.Node.Egress.Ipv6))])
                    self._leafs = OrderedDict()

                    self.ipv4 = AccessListHardware.Nodes.Node.Egress.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"

                    self.ipv6 = AccessListHardware.Nodes.Node.Egress.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"
                    self._segment_path = lambda: "egress"

                def __setattr__(self, name, value):
                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress, [], name, value)


                class Ipv4(Entity):
                    """
                    Accesslist version IPv4
                    
                    .. attribute:: accesses
                    
                    	Table for access lists
                    	**type**\:  :py:class:`Accesses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses>`
                    
                    

                    """

                    _prefix = 'ncs6k-acl-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(AccessListHardware.Nodes.Node.Egress.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "egress"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("accesses", ("accesses", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses))])
                        self._leafs = OrderedDict()

                        self.accesses = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses()
                        self.accesses.parent = self
                        self._children_name_map["accesses"] = "accesses"
                        self._segment_path = lambda: "ipv4"

                    def __setattr__(self, name, value):
                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4, [], name, value)


                    class Accesses(Entity):
                        """
                        Table for access lists
                        
                        .. attribute:: access
                        
                        	List of ACLs
                        	**type**\: list of  		 :py:class:`Access <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access>`
                        
                        

                        """

                        _prefix = 'ncs6k-acl-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses, self).__init__()

                            self.yang_name = "accesses"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("access", ("access", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access))])
                            self._leafs = OrderedDict()

                            self.access = YList(self)
                            self._segment_path = lambda: "accesses"

                        def __setattr__(self, name, value):
                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses, [], name, value)


                        class Access(Entity):
                            """
                            List of ACLs
                            
                            .. attribute:: access_list_name  (key)
                            
                            	Name of the access list
                            	**type**\: str
                            
                            .. attribute:: implicit
                            
                            	Implicit ACL information
                            	**type**\:  :py:class:`Implicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit>`
                            
                            .. attribute:: sequence_details
                            
                            	Table of all sequence numbers per ACL
                            	**type**\:  :py:class:`SequenceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails>`
                            
                            .. attribute:: sequence_briefs
                            
                            	Table of all sequence numbers per ACL
                            	**type**\:  :py:class:`SequenceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs>`
                            
                            

                            """

                            _prefix = 'ncs6k-acl-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access, self).__init__()

                                self.yang_name = "access"
                                self.yang_parent_name = "accesses"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['access_list_name']
                                self._child_classes = OrderedDict([("implicit", ("implicit", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit)), ("sequence-details", ("sequence_details", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails)), ("sequence-briefs", ("sequence_briefs", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs))])
                                self._leafs = OrderedDict([
                                    ('access_list_name', YLeaf(YType.str, 'access-list-name')),
                                ])
                                self.access_list_name = None

                                self.implicit = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit()
                                self.implicit.parent = self
                                self._children_name_map["implicit"] = "implicit"

                                self.sequence_details = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails()
                                self.sequence_details.parent = self
                                self._children_name_map["sequence_details"] = "sequence-details"

                                self.sequence_briefs = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs()
                                self.sequence_briefs.parent = self
                                self._children_name_map["sequence_briefs"] = "sequence-briefs"
                                self._segment_path = lambda: "access" + "[access-list-name='" + str(self.access_list_name) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access, ['access_list_name'], name, value)


                            class Implicit(Entity):
                                """
                                Implicit ACL information
                                
                                .. attribute:: implicit_acl
                                
                                	Implicit ACL Entries across Slices
                                	**type**\: list of  		 :py:class:`ImplicitAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit, self).__init__()

                                    self.yang_name = "implicit"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("implicit-acl", ("implicit_acl", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl))])
                                    self._leafs = OrderedDict()

                                    self.implicit_acl = YList(self)
                                    self._segment_path = lambda: "implicit"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit, [], name, value)


                                class ImplicitAcl(Entity):
                                    """
                                    Implicit ACL Entries across Slices
                                    
                                    .. attribute:: common_acl_implicit
                                    
                                    	Common ACL Implicit Entries
                                    	**type**\:  :py:class:`CommonAclImplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit>`
                                    
                                    .. attribute:: interface_acl_implicit
                                    
                                    	Interface ACL Implicit Entries
                                    	**type**\:  :py:class:`InterfaceAclImplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl, self).__init__()

                                        self.yang_name = "implicit-acl"
                                        self.yang_parent_name = "implicit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("common-acl-implicit", ("common_acl_implicit", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit)), ("interface-acl-implicit", ("interface_acl_implicit", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit))])
                                        self._leafs = OrderedDict()

                                        self.common_acl_implicit = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit()
                                        self.common_acl_implicit.parent = self
                                        self._children_name_map["common_acl_implicit"] = "common-acl-implicit"

                                        self.interface_acl_implicit = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit()
                                        self.interface_acl_implicit.parent = self
                                        self._children_name_map["interface_acl_implicit"] = "interface-acl-implicit"
                                        self._segment_path = lambda: "implicit-acl"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl, [], name, value)


                                    class CommonAclImplicit(Entity):
                                        """
                                        Common ACL Implicit Entries
                                        
                                        .. attribute:: implicit_ndna_permit
                                        
                                        	Implicit NDNA permit
                                        	**type**\:  :py:class:`ImplicitNdnaPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit>`
                                        
                                        .. attribute:: implicit_ndns_permit
                                        
                                        	Implicit NDNS permit
                                        	**type**\:  :py:class:`ImplicitNdnsPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit>`
                                        
                                        .. attribute:: implicit_deny
                                        
                                        	Implicit deny
                                        	**type**\:  :py:class:`ImplicitDeny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit, self).__init__()

                                            self.yang_name = "common-acl-implicit"
                                            self.yang_parent_name = "implicit-acl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("implicit-ndna-permit", ("implicit_ndna_permit", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit)), ("implicit-ndns-permit", ("implicit_ndns_permit", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit)), ("implicit-deny", ("implicit_deny", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny))])
                                            self._leafs = OrderedDict()

                                            self.implicit_ndna_permit = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit()
                                            self.implicit_ndna_permit.parent = self
                                            self._children_name_map["implicit_ndna_permit"] = "implicit-ndna-permit"

                                            self.implicit_ndns_permit = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit()
                                            self.implicit_ndns_permit.parent = self
                                            self._children_name_map["implicit_ndns_permit"] = "implicit-ndns-permit"

                                            self.implicit_deny = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny()
                                            self.implicit_deny.parent = self
                                            self._children_name_map["implicit_deny"] = "implicit-deny"
                                            self._segment_path = lambda: "common-acl-implicit"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit, [], name, value)


                                        class ImplicitNdnaPermit(Entity):
                                            """
                                            Implicit NDNA permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit, self).__init__()

                                                self.yang_name = "implicit-ndna-permit"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndna-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                        class ImplicitNdnsPermit(Entity):
                                            """
                                            Implicit NDNS permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit, self).__init__()

                                                self.yang_name = "implicit-ndns-permit"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndns-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                        class ImplicitDeny(Entity):
                                            """
                                            Implicit deny
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny, self).__init__()

                                                self.yang_name = "implicit-deny"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-deny"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                    class InterfaceAclImplicit(Entity):
                                        """
                                        Interface ACL Implicit Entries
                                        
                                        .. attribute:: implicit_ndna_permit
                                        
                                        	Implicit NDNA permit
                                        	**type**\:  :py:class:`ImplicitNdnaPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit>`
                                        
                                        .. attribute:: implicit_ndns_permit
                                        
                                        	Implicit NDNS permit
                                        	**type**\:  :py:class:`ImplicitNdnsPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit>`
                                        
                                        .. attribute:: implicit_deny
                                        
                                        	Implicit deny
                                        	**type**\:  :py:class:`ImplicitDeny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit, self).__init__()

                                            self.yang_name = "interface-acl-implicit"
                                            self.yang_parent_name = "implicit-acl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("implicit-ndna-permit", ("implicit_ndna_permit", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit)), ("implicit-ndns-permit", ("implicit_ndns_permit", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit)), ("implicit-deny", ("implicit_deny", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny))])
                                            self._leafs = OrderedDict()

                                            self.implicit_ndna_permit = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit()
                                            self.implicit_ndna_permit.parent = self
                                            self._children_name_map["implicit_ndna_permit"] = "implicit-ndna-permit"

                                            self.implicit_ndns_permit = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit()
                                            self.implicit_ndns_permit.parent = self
                                            self._children_name_map["implicit_ndns_permit"] = "implicit-ndns-permit"

                                            self.implicit_deny = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny()
                                            self.implicit_deny.parent = self
                                            self._children_name_map["implicit_deny"] = "implicit-deny"
                                            self._segment_path = lambda: "interface-acl-implicit"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit, [], name, value)


                                        class ImplicitNdnaPermit(Entity):
                                            """
                                            Implicit NDNA permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit, self).__init__()

                                                self.yang_name = "implicit-ndna-permit"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndna-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                        class ImplicitNdnsPermit(Entity):
                                            """
                                            Implicit NDNS permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit, self).__init__()

                                                self.yang_name = "implicit-ndns-permit"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndns-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                        class ImplicitDeny(Entity):
                                            """
                                            Implicit deny
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny, self).__init__()

                                                self.yang_name = "implicit-deny"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-deny"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                            class SequenceDetails(Entity):
                                """
                                Table of all sequence numbers per ACL
                                
                                .. attribute:: sequence_detail
                                
                                	Detail ACL information
                                	**type**\: list of  		 :py:class:`SequenceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails, self).__init__()

                                    self.yang_name = "sequence-details"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sequence-detail", ("sequence_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail))])
                                    self._leafs = OrderedDict()

                                    self.sequence_detail = YList(self)
                                    self._segment_path = lambda: "sequence-details"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails, [], name, value)


                                class SequenceDetail(Entity):
                                    """
                                    Detail ACL information
                                    
                                    .. attribute:: sequence_number  (key)
                                    
                                    	Detail ACL information for a particular sequence
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: common_acl_detail
                                    
                                    	Common ACL detail information across Slices
                                    	**type**\: list of  		 :py:class:`CommonAclDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail>`
                                    
                                    .. attribute:: interface_acl_detail
                                    
                                    	Interface ACL detail information across Slices
                                    	**type**\: list of  		 :py:class:`InterfaceAclDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail, self).__init__()

                                        self.yang_name = "sequence-detail"
                                        self.yang_parent_name = "sequence-details"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['sequence_number']
                                        self._child_classes = OrderedDict([("common-acl-detail", ("common_acl_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail)), ("interface-acl-detail", ("interface_acl_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail))])
                                        self._leafs = OrderedDict([
                                            ('sequence_number', YLeaf(YType.int32, 'sequence-number')),
                                        ])
                                        self.sequence_number = None

                                        self.common_acl_detail = YList(self)
                                        self.interface_acl_detail = YList(self)
                                        self._segment_path = lambda: "sequence-detail" + "[sequence-number='" + str(self.sequence_number) + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail, ['sequence_number'], name, value)


                                    class CommonAclDetail(Entity):
                                        """
                                        Common ACL detail information across Slices
                                        
                                        .. attribute:: ace_brief
                                        
                                        	ACE brief information
                                        	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief>`
                                        
                                        .. attribute:: ace_detail
                                        
                                        	ACE detail information
                                        	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail, self).__init__()

                                            self.yang_name = "common-acl-detail"
                                            self.yang_parent_name = "sequence-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail))])
                                            self._leafs = OrderedDict()

                                            self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief()
                                            self.ace_brief.parent = self
                                            self._children_name_map["ace_brief"] = "ace-brief"

                                            self.ace_detail = YList(self)
                                            self._segment_path = lambda: "common-acl-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail, [], name, value)


                                        class AceBrief(Entity):
                                            """
                                            ACE brief information
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress>`
                                            
                                            .. attribute:: grant
                                            
                                            	Either permit or deny
                                            	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                            
                                            .. attribute:: logging_enabled
                                            
                                            	Logging enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: per_ace_icmp_enabled
                                            
                                            	Per ACE ICMP enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: next_hop_enabled
                                            
                                            	Next hop enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: default_next_hop_enabled
                                            
                                            	Default next hop enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: total_tcam_entries
                                            
                                            	Number of TCAM entries
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: hits
                                            
                                            	Number of TCAM hits
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: npu_id
                                            
                                            	NPU Id
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief, self).__init__()

                                                self.yang_name = "ace-brief"
                                                self.yang_parent_name = "common-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress))])
                                                self._leafs = OrderedDict([
                                                    ('grant', YLeaf(YType.enumeration, 'grant')),
                                                    ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                    ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                    ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                    ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                    ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                    ('hits', YLeaf(YType.uint64, 'hits')),
                                                    ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                ])
                                                self.grant = None
                                                self.logging_enabled = None
                                                self.per_ace_icmp_enabled = None
                                                self.next_hop_enabled = None
                                                self.default_next_hop_enabled = None
                                                self.total_tcam_entries = None
                                                self.hits = None
                                                self.npu_id = None

                                                self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress()
                                                self.next_hop_address.parent = self
                                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                                self._segment_path = lambda: "ace-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                            class NextHopAddress(Entity):
                                                """
                                                Next hop address
                                                
                                                .. attribute:: address_type
                                                
                                                	AddressType
                                                	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress, self).__init__()

                                                    self.yang_name = "next-hop-address"
                                                    self.yang_parent_name = "ace-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                    ])
                                                    self.address_type = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "next-hop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                        class AceDetail(Entity):
                                            """
                                            ACE detail information
                                            
                                            .. attribute:: ipv4tcam
                                            
                                            	IPv4 TCAM entries
                                            	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam>`
                                            
                                            .. attribute:: ipv6tcam
                                            
                                            	IPv6 TCAM entries
                                            	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam>`
                                            
                                            .. attribute:: entry_id
                                            
                                            	Entry ID
                                            	**type**\: int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail, self).__init__()

                                                self.yang_name = "ace-detail"
                                                self.yang_parent_name = "common-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam))])
                                                self._leafs = OrderedDict([
                                                    ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                ])
                                                self.entry_id = None

                                                self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam()
                                                self.ipv4tcam.parent = self
                                                self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam()
                                                self.ipv6tcam.parent = self
                                                self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                self._segment_path = lambda: "ace-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail, ['entry_id'], name, value)


                                            class Ipv4tcam(Entity):
                                                """
                                                IPv4 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam, self).__init__()

                                                    self.yang_name = "ipv4tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry))])
                                                    self._leafs = OrderedDict()

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._segment_path = lambda: "ipv4tcam"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam, [], name, value)


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Pfilter IPv4 TCAM value
                                                    	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	Pfilter IPv4 TCAM mask
                                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	Pfilter IPv4 TCAM result
                                                    	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv4tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                        self._leafs = OrderedDict()

                                                        self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"

                                                        self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"

                                                        self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                    class Value(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM value
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM mask
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM result
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                            class Ipv6tcam(Entity):
                                                """
                                                IPv6 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam, self).__init__()

                                                    self.yang_name = "ipv6tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry))])
                                                    self._leafs = OrderedDict()

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._segment_path = lambda: "ipv6tcam"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam, [], name, value)


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: value
                                                    
                                                    	IPv6 TCAM value
                                                    	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	IPv6 TCAM mask
                                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	IPv6 TCAM result
                                                    	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: source_address
                                                    
                                                    	Source address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: source_address_mask
                                                    
                                                    	Source address mask
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address
                                                    
                                                    	Destination address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address_mask
                                                    
                                                    	Destination address mask
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv6tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                        self._leafs = OrderedDict([
                                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                                            ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                            ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                            ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                        ])
                                                        self.source_address = None
                                                        self.source_address_mask = None
                                                        self.destination_address = None
                                                        self.destination_address_mask = None

                                                        self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"

                                                        self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"

                                                        self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        IPv6 TCAM value
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        IPv6 TCAM mask
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        IPv6 TCAM result
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                    class InterfaceAclDetail(Entity):
                                        """
                                        Interface ACL detail information across Slices
                                        
                                        .. attribute:: ace_brief
                                        
                                        	ACE brief information
                                        	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief>`
                                        
                                        .. attribute:: ace_detail
                                        
                                        	ACE detail information
                                        	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail, self).__init__()

                                            self.yang_name = "interface-acl-detail"
                                            self.yang_parent_name = "sequence-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail))])
                                            self._leafs = OrderedDict()

                                            self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief()
                                            self.ace_brief.parent = self
                                            self._children_name_map["ace_brief"] = "ace-brief"

                                            self.ace_detail = YList(self)
                                            self._segment_path = lambda: "interface-acl-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail, [], name, value)


                                        class AceBrief(Entity):
                                            """
                                            ACE brief information
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress>`
                                            
                                            .. attribute:: grant
                                            
                                            	Either permit or deny
                                            	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                            
                                            .. attribute:: logging_enabled
                                            
                                            	Logging enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: per_ace_icmp_enabled
                                            
                                            	Per ACE ICMP enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: next_hop_enabled
                                            
                                            	Next hop enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: default_next_hop_enabled
                                            
                                            	Default next hop enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: total_tcam_entries
                                            
                                            	Number of TCAM entries
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: hits
                                            
                                            	Number of TCAM hits
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: npu_id
                                            
                                            	NPU Id
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief, self).__init__()

                                                self.yang_name = "ace-brief"
                                                self.yang_parent_name = "interface-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress))])
                                                self._leafs = OrderedDict([
                                                    ('grant', YLeaf(YType.enumeration, 'grant')),
                                                    ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                    ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                    ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                    ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                    ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                    ('hits', YLeaf(YType.uint64, 'hits')),
                                                    ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                ])
                                                self.grant = None
                                                self.logging_enabled = None
                                                self.per_ace_icmp_enabled = None
                                                self.next_hop_enabled = None
                                                self.default_next_hop_enabled = None
                                                self.total_tcam_entries = None
                                                self.hits = None
                                                self.npu_id = None

                                                self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress()
                                                self.next_hop_address.parent = self
                                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                                self._segment_path = lambda: "ace-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                            class NextHopAddress(Entity):
                                                """
                                                Next hop address
                                                
                                                .. attribute:: address_type
                                                
                                                	AddressType
                                                	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress, self).__init__()

                                                    self.yang_name = "next-hop-address"
                                                    self.yang_parent_name = "ace-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                    ])
                                                    self.address_type = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "next-hop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                        class AceDetail(Entity):
                                            """
                                            ACE detail information
                                            
                                            .. attribute:: ipv4tcam
                                            
                                            	IPv4 TCAM entries
                                            	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam>`
                                            
                                            .. attribute:: ipv6tcam
                                            
                                            	IPv6 TCAM entries
                                            	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam>`
                                            
                                            .. attribute:: entry_id
                                            
                                            	Entry ID
                                            	**type**\: int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail, self).__init__()

                                                self.yang_name = "ace-detail"
                                                self.yang_parent_name = "interface-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam))])
                                                self._leafs = OrderedDict([
                                                    ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                ])
                                                self.entry_id = None

                                                self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam()
                                                self.ipv4tcam.parent = self
                                                self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam()
                                                self.ipv6tcam.parent = self
                                                self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                self._segment_path = lambda: "ace-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail, ['entry_id'], name, value)


                                            class Ipv4tcam(Entity):
                                                """
                                                IPv4 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam, self).__init__()

                                                    self.yang_name = "ipv4tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry))])
                                                    self._leafs = OrderedDict()

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._segment_path = lambda: "ipv4tcam"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam, [], name, value)


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Pfilter IPv4 TCAM value
                                                    	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	Pfilter IPv4 TCAM mask
                                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	Pfilter IPv4 TCAM result
                                                    	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv4tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                        self._leafs = OrderedDict()

                                                        self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"

                                                        self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"

                                                        self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                    class Value(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM value
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM mask
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM result
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                            class Ipv6tcam(Entity):
                                                """
                                                IPv6 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam, self).__init__()

                                                    self.yang_name = "ipv6tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry))])
                                                    self._leafs = OrderedDict()

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._segment_path = lambda: "ipv6tcam"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam, [], name, value)


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: value
                                                    
                                                    	IPv6 TCAM value
                                                    	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	IPv6 TCAM mask
                                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	IPv6 TCAM result
                                                    	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: source_address
                                                    
                                                    	Source address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: source_address_mask
                                                    
                                                    	Source address mask
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address
                                                    
                                                    	Destination address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address_mask
                                                    
                                                    	Destination address mask
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv6tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                        self._leafs = OrderedDict([
                                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                                            ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                            ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                            ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                        ])
                                                        self.source_address = None
                                                        self.source_address_mask = None
                                                        self.destination_address = None
                                                        self.destination_address_mask = None

                                                        self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"

                                                        self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"

                                                        self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        IPv6 TCAM value
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        IPv6 TCAM mask
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        IPv6 TCAM result
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                            class SequenceBriefs(Entity):
                                """
                                Table of all sequence numbers per ACL
                                
                                .. attribute:: sequence_brief
                                
                                	Detail ACL information
                                	**type**\: list of  		 :py:class:`SequenceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs, self).__init__()

                                    self.yang_name = "sequence-briefs"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sequence-brief", ("sequence_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief))])
                                    self._leafs = OrderedDict()

                                    self.sequence_brief = YList(self)
                                    self._segment_path = lambda: "sequence-briefs"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs, [], name, value)


                                class SequenceBrief(Entity):
                                    """
                                    Detail ACL information
                                    
                                    .. attribute:: sequence_number  (key)
                                    
                                    	Brief ACL information for a particular sequence
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: common_acl
                                    
                                    	Common ACL information across Slices
                                    	**type**\: list of  		 :py:class:`CommonAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl>`
                                    
                                    .. attribute:: interface_acl
                                    
                                    	Interface ACL information across Slices
                                    	**type**\: list of  		 :py:class:`InterfaceAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief, self).__init__()

                                        self.yang_name = "sequence-brief"
                                        self.yang_parent_name = "sequence-briefs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['sequence_number']
                                        self._child_classes = OrderedDict([("common-acl", ("common_acl", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl)), ("interface-acl", ("interface_acl", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl))])
                                        self._leafs = OrderedDict([
                                            ('sequence_number', YLeaf(YType.int32, 'sequence-number')),
                                        ])
                                        self.sequence_number = None

                                        self.common_acl = YList(self)
                                        self.interface_acl = YList(self)
                                        self._segment_path = lambda: "sequence-brief" + "[sequence-number='" + str(self.sequence_number) + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief, ['sequence_number'], name, value)


                                    class CommonAcl(Entity):
                                        """
                                        Common ACL information across Slices
                                        
                                        .. attribute:: next_hop_address
                                        
                                        	Next hop address
                                        	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress>`
                                        
                                        .. attribute:: grant
                                        
                                        	Either permit or deny
                                        	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                        
                                        .. attribute:: logging_enabled
                                        
                                        	Logging enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: per_ace_icmp_enabled
                                        
                                        	Per ACE ICMP enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: next_hop_enabled
                                        
                                        	Next hop enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: default_next_hop_enabled
                                        
                                        	Default next hop enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: total_tcam_entries
                                        
                                        	Number of TCAM entries
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: hits
                                        
                                        	Number of TCAM hits
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: npu_id
                                        
                                        	NPU Id
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl, self).__init__()

                                            self.yang_name = "common-acl"
                                            self.yang_parent_name = "sequence-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress))])
                                            self._leafs = OrderedDict([
                                                ('grant', YLeaf(YType.enumeration, 'grant')),
                                                ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                ('hits', YLeaf(YType.uint64, 'hits')),
                                                ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                            ])
                                            self.grant = None
                                            self.logging_enabled = None
                                            self.per_ace_icmp_enabled = None
                                            self.next_hop_enabled = None
                                            self.default_next_hop_enabled = None
                                            self.total_tcam_entries = None
                                            self.hits = None
                                            self.npu_id = None

                                            self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                            self._segment_path = lambda: "common-acl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                        class NextHopAddress(Entity):
                                            """
                                            Next hop address
                                            
                                            .. attribute:: address_type
                                            
                                            	AddressType
                                            	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress, self).__init__()

                                                self.yang_name = "next-hop-address"
                                                self.yang_parent_name = "common-acl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                ])
                                                self.address_type = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "next-hop-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                    class InterfaceAcl(Entity):
                                        """
                                        Interface ACL information across Slices
                                        
                                        .. attribute:: next_hop_address
                                        
                                        	Next hop address
                                        	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress>`
                                        
                                        .. attribute:: grant
                                        
                                        	Either permit or deny
                                        	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                        
                                        .. attribute:: logging_enabled
                                        
                                        	Logging enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: per_ace_icmp_enabled
                                        
                                        	Per ACE ICMP enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: next_hop_enabled
                                        
                                        	Next hop enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: default_next_hop_enabled
                                        
                                        	Default next hop enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: total_tcam_entries
                                        
                                        	Number of TCAM entries
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: hits
                                        
                                        	Number of TCAM hits
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: npu_id
                                        
                                        	NPU Id
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl, self).__init__()

                                            self.yang_name = "interface-acl"
                                            self.yang_parent_name = "sequence-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress))])
                                            self._leafs = OrderedDict([
                                                ('grant', YLeaf(YType.enumeration, 'grant')),
                                                ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                ('hits', YLeaf(YType.uint64, 'hits')),
                                                ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                            ])
                                            self.grant = None
                                            self.logging_enabled = None
                                            self.per_ace_icmp_enabled = None
                                            self.next_hop_enabled = None
                                            self.default_next_hop_enabled = None
                                            self.total_tcam_entries = None
                                            self.hits = None
                                            self.npu_id = None

                                            self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                            self._segment_path = lambda: "interface-acl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                        class NextHopAddress(Entity):
                                            """
                                            Next hop address
                                            
                                            .. attribute:: address_type
                                            
                                            	AddressType
                                            	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress, self).__init__()

                                                self.yang_name = "next-hop-address"
                                                self.yang_parent_name = "interface-acl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                ])
                                                self.address_type = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "next-hop-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                class Ipv6(Entity):
                    """
                    Accesslist version IPv6
                    
                    .. attribute:: accesses
                    
                    	Table for access lists
                    	**type**\:  :py:class:`Accesses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses>`
                    
                    

                    """

                    _prefix = 'ncs6k-acl-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(AccessListHardware.Nodes.Node.Egress.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "egress"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("accesses", ("accesses", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses))])
                        self._leafs = OrderedDict()

                        self.accesses = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses()
                        self.accesses.parent = self
                        self._children_name_map["accesses"] = "accesses"
                        self._segment_path = lambda: "ipv6"

                    def __setattr__(self, name, value):
                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6, [], name, value)


                    class Accesses(Entity):
                        """
                        Table for access lists
                        
                        .. attribute:: access
                        
                        	List of ACLs
                        	**type**\: list of  		 :py:class:`Access <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access>`
                        
                        

                        """

                        _prefix = 'ncs6k-acl-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses, self).__init__()

                            self.yang_name = "accesses"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("access", ("access", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access))])
                            self._leafs = OrderedDict()

                            self.access = YList(self)
                            self._segment_path = lambda: "accesses"

                        def __setattr__(self, name, value):
                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses, [], name, value)


                        class Access(Entity):
                            """
                            List of ACLs
                            
                            .. attribute:: access_list_name  (key)
                            
                            	Name of the access list
                            	**type**\: str
                            
                            .. attribute:: implicit
                            
                            	Implicit ACL information
                            	**type**\:  :py:class:`Implicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit>`
                            
                            .. attribute:: sequence_details
                            
                            	Table of all sequence numbers per ACL
                            	**type**\:  :py:class:`SequenceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails>`
                            
                            .. attribute:: sequence_briefs
                            
                            	Table of all sequence numbers per ACL
                            	**type**\:  :py:class:`SequenceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs>`
                            
                            

                            """

                            _prefix = 'ncs6k-acl-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access, self).__init__()

                                self.yang_name = "access"
                                self.yang_parent_name = "accesses"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['access_list_name']
                                self._child_classes = OrderedDict([("implicit", ("implicit", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit)), ("sequence-details", ("sequence_details", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails)), ("sequence-briefs", ("sequence_briefs", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs))])
                                self._leafs = OrderedDict([
                                    ('access_list_name', YLeaf(YType.str, 'access-list-name')),
                                ])
                                self.access_list_name = None

                                self.implicit = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit()
                                self.implicit.parent = self
                                self._children_name_map["implicit"] = "implicit"

                                self.sequence_details = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails()
                                self.sequence_details.parent = self
                                self._children_name_map["sequence_details"] = "sequence-details"

                                self.sequence_briefs = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs()
                                self.sequence_briefs.parent = self
                                self._children_name_map["sequence_briefs"] = "sequence-briefs"
                                self._segment_path = lambda: "access" + "[access-list-name='" + str(self.access_list_name) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access, ['access_list_name'], name, value)


                            class Implicit(Entity):
                                """
                                Implicit ACL information
                                
                                .. attribute:: implicit_acl
                                
                                	Implicit ACL Entries across Slices
                                	**type**\: list of  		 :py:class:`ImplicitAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit, self).__init__()

                                    self.yang_name = "implicit"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("implicit-acl", ("implicit_acl", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl))])
                                    self._leafs = OrderedDict()

                                    self.implicit_acl = YList(self)
                                    self._segment_path = lambda: "implicit"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit, [], name, value)


                                class ImplicitAcl(Entity):
                                    """
                                    Implicit ACL Entries across Slices
                                    
                                    .. attribute:: common_acl_implicit
                                    
                                    	Common ACL Implicit Entries
                                    	**type**\:  :py:class:`CommonAclImplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit>`
                                    
                                    .. attribute:: interface_acl_implicit
                                    
                                    	Interface ACL Implicit Entries
                                    	**type**\:  :py:class:`InterfaceAclImplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl, self).__init__()

                                        self.yang_name = "implicit-acl"
                                        self.yang_parent_name = "implicit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("common-acl-implicit", ("common_acl_implicit", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit)), ("interface-acl-implicit", ("interface_acl_implicit", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit))])
                                        self._leafs = OrderedDict()

                                        self.common_acl_implicit = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit()
                                        self.common_acl_implicit.parent = self
                                        self._children_name_map["common_acl_implicit"] = "common-acl-implicit"

                                        self.interface_acl_implicit = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit()
                                        self.interface_acl_implicit.parent = self
                                        self._children_name_map["interface_acl_implicit"] = "interface-acl-implicit"
                                        self._segment_path = lambda: "implicit-acl"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl, [], name, value)


                                    class CommonAclImplicit(Entity):
                                        """
                                        Common ACL Implicit Entries
                                        
                                        .. attribute:: implicit_ndna_permit
                                        
                                        	Implicit NDNA permit
                                        	**type**\:  :py:class:`ImplicitNdnaPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit>`
                                        
                                        .. attribute:: implicit_ndns_permit
                                        
                                        	Implicit NDNS permit
                                        	**type**\:  :py:class:`ImplicitNdnsPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit>`
                                        
                                        .. attribute:: implicit_deny
                                        
                                        	Implicit deny
                                        	**type**\:  :py:class:`ImplicitDeny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit, self).__init__()

                                            self.yang_name = "common-acl-implicit"
                                            self.yang_parent_name = "implicit-acl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("implicit-ndna-permit", ("implicit_ndna_permit", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit)), ("implicit-ndns-permit", ("implicit_ndns_permit", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit)), ("implicit-deny", ("implicit_deny", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny))])
                                            self._leafs = OrderedDict()

                                            self.implicit_ndna_permit = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit()
                                            self.implicit_ndna_permit.parent = self
                                            self._children_name_map["implicit_ndna_permit"] = "implicit-ndna-permit"

                                            self.implicit_ndns_permit = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit()
                                            self.implicit_ndns_permit.parent = self
                                            self._children_name_map["implicit_ndns_permit"] = "implicit-ndns-permit"

                                            self.implicit_deny = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny()
                                            self.implicit_deny.parent = self
                                            self._children_name_map["implicit_deny"] = "implicit-deny"
                                            self._segment_path = lambda: "common-acl-implicit"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit, [], name, value)


                                        class ImplicitNdnaPermit(Entity):
                                            """
                                            Implicit NDNA permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit, self).__init__()

                                                self.yang_name = "implicit-ndna-permit"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndna-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                        class ImplicitNdnsPermit(Entity):
                                            """
                                            Implicit NDNS permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit, self).__init__()

                                                self.yang_name = "implicit-ndns-permit"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndns-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                        class ImplicitDeny(Entity):
                                            """
                                            Implicit deny
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny, self).__init__()

                                                self.yang_name = "implicit-deny"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-deny"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                    class InterfaceAclImplicit(Entity):
                                        """
                                        Interface ACL Implicit Entries
                                        
                                        .. attribute:: implicit_ndna_permit
                                        
                                        	Implicit NDNA permit
                                        	**type**\:  :py:class:`ImplicitNdnaPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit>`
                                        
                                        .. attribute:: implicit_ndns_permit
                                        
                                        	Implicit NDNS permit
                                        	**type**\:  :py:class:`ImplicitNdnsPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit>`
                                        
                                        .. attribute:: implicit_deny
                                        
                                        	Implicit deny
                                        	**type**\:  :py:class:`ImplicitDeny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit, self).__init__()

                                            self.yang_name = "interface-acl-implicit"
                                            self.yang_parent_name = "implicit-acl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("implicit-ndna-permit", ("implicit_ndna_permit", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit)), ("implicit-ndns-permit", ("implicit_ndns_permit", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit)), ("implicit-deny", ("implicit_deny", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny))])
                                            self._leafs = OrderedDict()

                                            self.implicit_ndna_permit = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit()
                                            self.implicit_ndna_permit.parent = self
                                            self._children_name_map["implicit_ndna_permit"] = "implicit-ndna-permit"

                                            self.implicit_ndns_permit = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit()
                                            self.implicit_ndns_permit.parent = self
                                            self._children_name_map["implicit_ndns_permit"] = "implicit-ndns-permit"

                                            self.implicit_deny = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny()
                                            self.implicit_deny.parent = self
                                            self._children_name_map["implicit_deny"] = "implicit-deny"
                                            self._segment_path = lambda: "interface-acl-implicit"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit, [], name, value)


                                        class ImplicitNdnaPermit(Entity):
                                            """
                                            Implicit NDNA permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit, self).__init__()

                                                self.yang_name = "implicit-ndna-permit"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndna-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                        class ImplicitNdnsPermit(Entity):
                                            """
                                            Implicit NDNS permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit, self).__init__()

                                                self.yang_name = "implicit-ndns-permit"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndns-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                        class ImplicitDeny(Entity):
                                            """
                                            Implicit deny
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny, self).__init__()

                                                self.yang_name = "implicit-deny"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-deny"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                            class SequenceDetails(Entity):
                                """
                                Table of all sequence numbers per ACL
                                
                                .. attribute:: sequence_detail
                                
                                	Detail ACL information
                                	**type**\: list of  		 :py:class:`SequenceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails, self).__init__()

                                    self.yang_name = "sequence-details"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sequence-detail", ("sequence_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail))])
                                    self._leafs = OrderedDict()

                                    self.sequence_detail = YList(self)
                                    self._segment_path = lambda: "sequence-details"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails, [], name, value)


                                class SequenceDetail(Entity):
                                    """
                                    Detail ACL information
                                    
                                    .. attribute:: sequence_number  (key)
                                    
                                    	Detail ACL information for a particular sequence
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: common_acl_detail
                                    
                                    	Common ACL detail information across Slices
                                    	**type**\: list of  		 :py:class:`CommonAclDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail>`
                                    
                                    .. attribute:: interface_acl_detail
                                    
                                    	Interface ACL detail information across Slices
                                    	**type**\: list of  		 :py:class:`InterfaceAclDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail, self).__init__()

                                        self.yang_name = "sequence-detail"
                                        self.yang_parent_name = "sequence-details"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['sequence_number']
                                        self._child_classes = OrderedDict([("common-acl-detail", ("common_acl_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail)), ("interface-acl-detail", ("interface_acl_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail))])
                                        self._leafs = OrderedDict([
                                            ('sequence_number', YLeaf(YType.int32, 'sequence-number')),
                                        ])
                                        self.sequence_number = None

                                        self.common_acl_detail = YList(self)
                                        self.interface_acl_detail = YList(self)
                                        self._segment_path = lambda: "sequence-detail" + "[sequence-number='" + str(self.sequence_number) + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail, ['sequence_number'], name, value)


                                    class CommonAclDetail(Entity):
                                        """
                                        Common ACL detail information across Slices
                                        
                                        .. attribute:: ace_brief
                                        
                                        	ACE brief information
                                        	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief>`
                                        
                                        .. attribute:: ace_detail
                                        
                                        	ACE detail information
                                        	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail, self).__init__()

                                            self.yang_name = "common-acl-detail"
                                            self.yang_parent_name = "sequence-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail))])
                                            self._leafs = OrderedDict()

                                            self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief()
                                            self.ace_brief.parent = self
                                            self._children_name_map["ace_brief"] = "ace-brief"

                                            self.ace_detail = YList(self)
                                            self._segment_path = lambda: "common-acl-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail, [], name, value)


                                        class AceBrief(Entity):
                                            """
                                            ACE brief information
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress>`
                                            
                                            .. attribute:: grant
                                            
                                            	Either permit or deny
                                            	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                            
                                            .. attribute:: logging_enabled
                                            
                                            	Logging enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: per_ace_icmp_enabled
                                            
                                            	Per ACE ICMP enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: next_hop_enabled
                                            
                                            	Next hop enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: default_next_hop_enabled
                                            
                                            	Default next hop enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: total_tcam_entries
                                            
                                            	Number of TCAM entries
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: hits
                                            
                                            	Number of TCAM hits
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: npu_id
                                            
                                            	NPU Id
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief, self).__init__()

                                                self.yang_name = "ace-brief"
                                                self.yang_parent_name = "common-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress))])
                                                self._leafs = OrderedDict([
                                                    ('grant', YLeaf(YType.enumeration, 'grant')),
                                                    ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                    ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                    ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                    ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                    ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                    ('hits', YLeaf(YType.uint64, 'hits')),
                                                    ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                ])
                                                self.grant = None
                                                self.logging_enabled = None
                                                self.per_ace_icmp_enabled = None
                                                self.next_hop_enabled = None
                                                self.default_next_hop_enabled = None
                                                self.total_tcam_entries = None
                                                self.hits = None
                                                self.npu_id = None

                                                self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress()
                                                self.next_hop_address.parent = self
                                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                                self._segment_path = lambda: "ace-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                            class NextHopAddress(Entity):
                                                """
                                                Next hop address
                                                
                                                .. attribute:: address_type
                                                
                                                	AddressType
                                                	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress, self).__init__()

                                                    self.yang_name = "next-hop-address"
                                                    self.yang_parent_name = "ace-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                    ])
                                                    self.address_type = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "next-hop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                        class AceDetail(Entity):
                                            """
                                            ACE detail information
                                            
                                            .. attribute:: ipv4tcam
                                            
                                            	IPv4 TCAM entries
                                            	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam>`
                                            
                                            .. attribute:: ipv6tcam
                                            
                                            	IPv6 TCAM entries
                                            	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam>`
                                            
                                            .. attribute:: entry_id
                                            
                                            	Entry ID
                                            	**type**\: int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail, self).__init__()

                                                self.yang_name = "ace-detail"
                                                self.yang_parent_name = "common-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam))])
                                                self._leafs = OrderedDict([
                                                    ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                ])
                                                self.entry_id = None

                                                self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam()
                                                self.ipv4tcam.parent = self
                                                self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam()
                                                self.ipv6tcam.parent = self
                                                self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                self._segment_path = lambda: "ace-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail, ['entry_id'], name, value)


                                            class Ipv4tcam(Entity):
                                                """
                                                IPv4 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam, self).__init__()

                                                    self.yang_name = "ipv4tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry))])
                                                    self._leafs = OrderedDict()

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._segment_path = lambda: "ipv4tcam"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam, [], name, value)


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Pfilter IPv4 TCAM value
                                                    	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	Pfilter IPv4 TCAM mask
                                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	Pfilter IPv4 TCAM result
                                                    	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv4tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                        self._leafs = OrderedDict()

                                                        self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"

                                                        self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"

                                                        self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                    class Value(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM value
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM mask
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM result
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                            class Ipv6tcam(Entity):
                                                """
                                                IPv6 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam, self).__init__()

                                                    self.yang_name = "ipv6tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry))])
                                                    self._leafs = OrderedDict()

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._segment_path = lambda: "ipv6tcam"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam, [], name, value)


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: value
                                                    
                                                    	IPv6 TCAM value
                                                    	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	IPv6 TCAM mask
                                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	IPv6 TCAM result
                                                    	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: source_address
                                                    
                                                    	Source address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: source_address_mask
                                                    
                                                    	Source address mask
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address
                                                    
                                                    	Destination address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address_mask
                                                    
                                                    	Destination address mask
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv6tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                        self._leafs = OrderedDict([
                                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                                            ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                            ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                            ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                        ])
                                                        self.source_address = None
                                                        self.source_address_mask = None
                                                        self.destination_address = None
                                                        self.destination_address_mask = None

                                                        self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"

                                                        self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"

                                                        self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        IPv6 TCAM value
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        IPv6 TCAM mask
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        IPv6 TCAM result
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                    class InterfaceAclDetail(Entity):
                                        """
                                        Interface ACL detail information across Slices
                                        
                                        .. attribute:: ace_brief
                                        
                                        	ACE brief information
                                        	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief>`
                                        
                                        .. attribute:: ace_detail
                                        
                                        	ACE detail information
                                        	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail, self).__init__()

                                            self.yang_name = "interface-acl-detail"
                                            self.yang_parent_name = "sequence-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail))])
                                            self._leafs = OrderedDict()

                                            self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief()
                                            self.ace_brief.parent = self
                                            self._children_name_map["ace_brief"] = "ace-brief"

                                            self.ace_detail = YList(self)
                                            self._segment_path = lambda: "interface-acl-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail, [], name, value)


                                        class AceBrief(Entity):
                                            """
                                            ACE brief information
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress>`
                                            
                                            .. attribute:: grant
                                            
                                            	Either permit or deny
                                            	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                            
                                            .. attribute:: logging_enabled
                                            
                                            	Logging enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: per_ace_icmp_enabled
                                            
                                            	Per ACE ICMP enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: next_hop_enabled
                                            
                                            	Next hop enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: default_next_hop_enabled
                                            
                                            	Default next hop enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: total_tcam_entries
                                            
                                            	Number of TCAM entries
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: hits
                                            
                                            	Number of TCAM hits
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: npu_id
                                            
                                            	NPU Id
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief, self).__init__()

                                                self.yang_name = "ace-brief"
                                                self.yang_parent_name = "interface-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress))])
                                                self._leafs = OrderedDict([
                                                    ('grant', YLeaf(YType.enumeration, 'grant')),
                                                    ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                    ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                    ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                    ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                    ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                    ('hits', YLeaf(YType.uint64, 'hits')),
                                                    ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                ])
                                                self.grant = None
                                                self.logging_enabled = None
                                                self.per_ace_icmp_enabled = None
                                                self.next_hop_enabled = None
                                                self.default_next_hop_enabled = None
                                                self.total_tcam_entries = None
                                                self.hits = None
                                                self.npu_id = None

                                                self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress()
                                                self.next_hop_address.parent = self
                                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                                self._segment_path = lambda: "ace-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                            class NextHopAddress(Entity):
                                                """
                                                Next hop address
                                                
                                                .. attribute:: address_type
                                                
                                                	AddressType
                                                	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress, self).__init__()

                                                    self.yang_name = "next-hop-address"
                                                    self.yang_parent_name = "ace-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                    ])
                                                    self.address_type = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "next-hop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                        class AceDetail(Entity):
                                            """
                                            ACE detail information
                                            
                                            .. attribute:: ipv4tcam
                                            
                                            	IPv4 TCAM entries
                                            	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam>`
                                            
                                            .. attribute:: ipv6tcam
                                            
                                            	IPv6 TCAM entries
                                            	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam>`
                                            
                                            .. attribute:: entry_id
                                            
                                            	Entry ID
                                            	**type**\: int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail, self).__init__()

                                                self.yang_name = "ace-detail"
                                                self.yang_parent_name = "interface-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam))])
                                                self._leafs = OrderedDict([
                                                    ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                ])
                                                self.entry_id = None

                                                self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam()
                                                self.ipv4tcam.parent = self
                                                self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam()
                                                self.ipv6tcam.parent = self
                                                self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                self._segment_path = lambda: "ace-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail, ['entry_id'], name, value)


                                            class Ipv4tcam(Entity):
                                                """
                                                IPv4 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam, self).__init__()

                                                    self.yang_name = "ipv4tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry))])
                                                    self._leafs = OrderedDict()

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._segment_path = lambda: "ipv4tcam"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam, [], name, value)


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Pfilter IPv4 TCAM value
                                                    	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	Pfilter IPv4 TCAM mask
                                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	Pfilter IPv4 TCAM result
                                                    	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv4tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                        self._leafs = OrderedDict()

                                                        self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"

                                                        self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"

                                                        self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                    class Value(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM value
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM mask
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM result
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                            class Ipv6tcam(Entity):
                                                """
                                                IPv6 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam, self).__init__()

                                                    self.yang_name = "ipv6tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry))])
                                                    self._leafs = OrderedDict()

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._segment_path = lambda: "ipv6tcam"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam, [], name, value)


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: value
                                                    
                                                    	IPv6 TCAM value
                                                    	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	IPv6 TCAM mask
                                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	IPv6 TCAM result
                                                    	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: source_address
                                                    
                                                    	Source address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: source_address_mask
                                                    
                                                    	Source address mask
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address
                                                    
                                                    	Destination address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address_mask
                                                    
                                                    	Destination address mask
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv6tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                        self._leafs = OrderedDict([
                                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                                            ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                            ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                            ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                        ])
                                                        self.source_address = None
                                                        self.source_address_mask = None
                                                        self.destination_address = None
                                                        self.destination_address_mask = None

                                                        self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"

                                                        self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"

                                                        self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        IPv6 TCAM value
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        IPv6 TCAM mask
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        IPv6 TCAM result
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                            class SequenceBriefs(Entity):
                                """
                                Table of all sequence numbers per ACL
                                
                                .. attribute:: sequence_brief
                                
                                	Detail ACL information
                                	**type**\: list of  		 :py:class:`SequenceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs, self).__init__()

                                    self.yang_name = "sequence-briefs"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sequence-brief", ("sequence_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief))])
                                    self._leafs = OrderedDict()

                                    self.sequence_brief = YList(self)
                                    self._segment_path = lambda: "sequence-briefs"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs, [], name, value)


                                class SequenceBrief(Entity):
                                    """
                                    Detail ACL information
                                    
                                    .. attribute:: sequence_number  (key)
                                    
                                    	Brief ACL information for a particular sequence
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: common_acl
                                    
                                    	Common ACL information across Slices
                                    	**type**\: list of  		 :py:class:`CommonAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl>`
                                    
                                    .. attribute:: interface_acl
                                    
                                    	Interface ACL information across Slices
                                    	**type**\: list of  		 :py:class:`InterfaceAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief, self).__init__()

                                        self.yang_name = "sequence-brief"
                                        self.yang_parent_name = "sequence-briefs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['sequence_number']
                                        self._child_classes = OrderedDict([("common-acl", ("common_acl", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl)), ("interface-acl", ("interface_acl", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl))])
                                        self._leafs = OrderedDict([
                                            ('sequence_number', YLeaf(YType.int32, 'sequence-number')),
                                        ])
                                        self.sequence_number = None

                                        self.common_acl = YList(self)
                                        self.interface_acl = YList(self)
                                        self._segment_path = lambda: "sequence-brief" + "[sequence-number='" + str(self.sequence_number) + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief, ['sequence_number'], name, value)


                                    class CommonAcl(Entity):
                                        """
                                        Common ACL information across Slices
                                        
                                        .. attribute:: next_hop_address
                                        
                                        	Next hop address
                                        	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress>`
                                        
                                        .. attribute:: grant
                                        
                                        	Either permit or deny
                                        	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                        
                                        .. attribute:: logging_enabled
                                        
                                        	Logging enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: per_ace_icmp_enabled
                                        
                                        	Per ACE ICMP enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: next_hop_enabled
                                        
                                        	Next hop enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: default_next_hop_enabled
                                        
                                        	Default next hop enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: total_tcam_entries
                                        
                                        	Number of TCAM entries
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: hits
                                        
                                        	Number of TCAM hits
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: npu_id
                                        
                                        	NPU Id
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl, self).__init__()

                                            self.yang_name = "common-acl"
                                            self.yang_parent_name = "sequence-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress))])
                                            self._leafs = OrderedDict([
                                                ('grant', YLeaf(YType.enumeration, 'grant')),
                                                ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                ('hits', YLeaf(YType.uint64, 'hits')),
                                                ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                            ])
                                            self.grant = None
                                            self.logging_enabled = None
                                            self.per_ace_icmp_enabled = None
                                            self.next_hop_enabled = None
                                            self.default_next_hop_enabled = None
                                            self.total_tcam_entries = None
                                            self.hits = None
                                            self.npu_id = None

                                            self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                            self._segment_path = lambda: "common-acl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                        class NextHopAddress(Entity):
                                            """
                                            Next hop address
                                            
                                            .. attribute:: address_type
                                            
                                            	AddressType
                                            	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress, self).__init__()

                                                self.yang_name = "next-hop-address"
                                                self.yang_parent_name = "common-acl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                ])
                                                self.address_type = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "next-hop-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                    class InterfaceAcl(Entity):
                                        """
                                        Interface ACL information across Slices
                                        
                                        .. attribute:: next_hop_address
                                        
                                        	Next hop address
                                        	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress>`
                                        
                                        .. attribute:: grant
                                        
                                        	Either permit or deny
                                        	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                        
                                        .. attribute:: logging_enabled
                                        
                                        	Logging enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: per_ace_icmp_enabled
                                        
                                        	Per ACE ICMP enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: next_hop_enabled
                                        
                                        	Next hop enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: default_next_hop_enabled
                                        
                                        	Default next hop enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: total_tcam_entries
                                        
                                        	Number of TCAM entries
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: hits
                                        
                                        	Number of TCAM hits
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: npu_id
                                        
                                        	NPU Id
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl, self).__init__()

                                            self.yang_name = "interface-acl"
                                            self.yang_parent_name = "sequence-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress))])
                                            self._leafs = OrderedDict([
                                                ('grant', YLeaf(YType.enumeration, 'grant')),
                                                ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                ('hits', YLeaf(YType.uint64, 'hits')),
                                                ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                            ])
                                            self.grant = None
                                            self.logging_enabled = None
                                            self.per_ace_icmp_enabled = None
                                            self.next_hop_enabled = None
                                            self.default_next_hop_enabled = None
                                            self.total_tcam_entries = None
                                            self.hits = None
                                            self.npu_id = None

                                            self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                            self._segment_path = lambda: "interface-acl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                        class NextHopAddress(Entity):
                                            """
                                            Next hop address
                                            
                                            .. attribute:: address_type
                                            
                                            	AddressType
                                            	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress, self).__init__()

                                                self.yang_name = "next-hop-address"
                                                self.yang_parent_name = "interface-acl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                ])
                                                self.address_type = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "next-hop-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


            class Ingress(Entity):
                """
                Accesslist direction ingress
                
                .. attribute:: ipv4
                
                	Accesslist version IPv4
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4>`
                
                .. attribute:: ipv6
                
                	Accesslist version IPv6
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6>`
                
                

                """

                _prefix = 'ncs6k-acl-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(AccessListHardware.Nodes.Node.Ingress, self).__init__()

                    self.yang_name = "ingress"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4", ("ipv4", AccessListHardware.Nodes.Node.Ingress.Ipv4)), ("ipv6", ("ipv6", AccessListHardware.Nodes.Node.Ingress.Ipv6))])
                    self._leafs = OrderedDict()

                    self.ipv4 = AccessListHardware.Nodes.Node.Ingress.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"

                    self.ipv6 = AccessListHardware.Nodes.Node.Ingress.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"
                    self._segment_path = lambda: "ingress"

                def __setattr__(self, name, value):
                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress, [], name, value)


                class Ipv4(Entity):
                    """
                    Accesslist version IPv4
                    
                    .. attribute:: accesses
                    
                    	Table for access lists
                    	**type**\:  :py:class:`Accesses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses>`
                    
                    

                    """

                    _prefix = 'ncs6k-acl-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "ingress"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("accesses", ("accesses", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses))])
                        self._leafs = OrderedDict()

                        self.accesses = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses()
                        self.accesses.parent = self
                        self._children_name_map["accesses"] = "accesses"
                        self._segment_path = lambda: "ipv4"

                    def __setattr__(self, name, value):
                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4, [], name, value)


                    class Accesses(Entity):
                        """
                        Table for access lists
                        
                        .. attribute:: access
                        
                        	List of ACLs
                        	**type**\: list of  		 :py:class:`Access <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access>`
                        
                        

                        """

                        _prefix = 'ncs6k-acl-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses, self).__init__()

                            self.yang_name = "accesses"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("access", ("access", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access))])
                            self._leafs = OrderedDict()

                            self.access = YList(self)
                            self._segment_path = lambda: "accesses"

                        def __setattr__(self, name, value):
                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses, [], name, value)


                        class Access(Entity):
                            """
                            List of ACLs
                            
                            .. attribute:: access_list_name  (key)
                            
                            	Name of the access list
                            	**type**\: str
                            
                            .. attribute:: implicit
                            
                            	Implicit ACL information
                            	**type**\:  :py:class:`Implicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit>`
                            
                            .. attribute:: sequence_details
                            
                            	Table of all sequence numbers per ACL
                            	**type**\:  :py:class:`SequenceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails>`
                            
                            .. attribute:: sequence_briefs
                            
                            	Table of all sequence numbers per ACL
                            	**type**\:  :py:class:`SequenceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs>`
                            
                            

                            """

                            _prefix = 'ncs6k-acl-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access, self).__init__()

                                self.yang_name = "access"
                                self.yang_parent_name = "accesses"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['access_list_name']
                                self._child_classes = OrderedDict([("implicit", ("implicit", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit)), ("sequence-details", ("sequence_details", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails)), ("sequence-briefs", ("sequence_briefs", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs))])
                                self._leafs = OrderedDict([
                                    ('access_list_name', YLeaf(YType.str, 'access-list-name')),
                                ])
                                self.access_list_name = None

                                self.implicit = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit()
                                self.implicit.parent = self
                                self._children_name_map["implicit"] = "implicit"

                                self.sequence_details = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails()
                                self.sequence_details.parent = self
                                self._children_name_map["sequence_details"] = "sequence-details"

                                self.sequence_briefs = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs()
                                self.sequence_briefs.parent = self
                                self._children_name_map["sequence_briefs"] = "sequence-briefs"
                                self._segment_path = lambda: "access" + "[access-list-name='" + str(self.access_list_name) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access, ['access_list_name'], name, value)


                            class Implicit(Entity):
                                """
                                Implicit ACL information
                                
                                .. attribute:: implicit_acl
                                
                                	Implicit ACL Entries across Slices
                                	**type**\: list of  		 :py:class:`ImplicitAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit, self).__init__()

                                    self.yang_name = "implicit"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("implicit-acl", ("implicit_acl", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl))])
                                    self._leafs = OrderedDict()

                                    self.implicit_acl = YList(self)
                                    self._segment_path = lambda: "implicit"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit, [], name, value)


                                class ImplicitAcl(Entity):
                                    """
                                    Implicit ACL Entries across Slices
                                    
                                    .. attribute:: common_acl_implicit
                                    
                                    	Common ACL Implicit Entries
                                    	**type**\:  :py:class:`CommonAclImplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit>`
                                    
                                    .. attribute:: interface_acl_implicit
                                    
                                    	Interface ACL Implicit Entries
                                    	**type**\:  :py:class:`InterfaceAclImplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl, self).__init__()

                                        self.yang_name = "implicit-acl"
                                        self.yang_parent_name = "implicit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("common-acl-implicit", ("common_acl_implicit", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit)), ("interface-acl-implicit", ("interface_acl_implicit", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit))])
                                        self._leafs = OrderedDict()

                                        self.common_acl_implicit = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit()
                                        self.common_acl_implicit.parent = self
                                        self._children_name_map["common_acl_implicit"] = "common-acl-implicit"

                                        self.interface_acl_implicit = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit()
                                        self.interface_acl_implicit.parent = self
                                        self._children_name_map["interface_acl_implicit"] = "interface-acl-implicit"
                                        self._segment_path = lambda: "implicit-acl"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl, [], name, value)


                                    class CommonAclImplicit(Entity):
                                        """
                                        Common ACL Implicit Entries
                                        
                                        .. attribute:: implicit_ndna_permit
                                        
                                        	Implicit NDNA permit
                                        	**type**\:  :py:class:`ImplicitNdnaPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit>`
                                        
                                        .. attribute:: implicit_ndns_permit
                                        
                                        	Implicit NDNS permit
                                        	**type**\:  :py:class:`ImplicitNdnsPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit>`
                                        
                                        .. attribute:: implicit_deny
                                        
                                        	Implicit deny
                                        	**type**\:  :py:class:`ImplicitDeny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit, self).__init__()

                                            self.yang_name = "common-acl-implicit"
                                            self.yang_parent_name = "implicit-acl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("implicit-ndna-permit", ("implicit_ndna_permit", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit)), ("implicit-ndns-permit", ("implicit_ndns_permit", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit)), ("implicit-deny", ("implicit_deny", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny))])
                                            self._leafs = OrderedDict()

                                            self.implicit_ndna_permit = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit()
                                            self.implicit_ndna_permit.parent = self
                                            self._children_name_map["implicit_ndna_permit"] = "implicit-ndna-permit"

                                            self.implicit_ndns_permit = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit()
                                            self.implicit_ndns_permit.parent = self
                                            self._children_name_map["implicit_ndns_permit"] = "implicit-ndns-permit"

                                            self.implicit_deny = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny()
                                            self.implicit_deny.parent = self
                                            self._children_name_map["implicit_deny"] = "implicit-deny"
                                            self._segment_path = lambda: "common-acl-implicit"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit, [], name, value)


                                        class ImplicitNdnaPermit(Entity):
                                            """
                                            Implicit NDNA permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit, self).__init__()

                                                self.yang_name = "implicit-ndna-permit"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndna-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                        class ImplicitNdnsPermit(Entity):
                                            """
                                            Implicit NDNS permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit, self).__init__()

                                                self.yang_name = "implicit-ndns-permit"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndns-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                        class ImplicitDeny(Entity):
                                            """
                                            Implicit deny
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny, self).__init__()

                                                self.yang_name = "implicit-deny"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-deny"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                    class InterfaceAclImplicit(Entity):
                                        """
                                        Interface ACL Implicit Entries
                                        
                                        .. attribute:: implicit_ndna_permit
                                        
                                        	Implicit NDNA permit
                                        	**type**\:  :py:class:`ImplicitNdnaPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit>`
                                        
                                        .. attribute:: implicit_ndns_permit
                                        
                                        	Implicit NDNS permit
                                        	**type**\:  :py:class:`ImplicitNdnsPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit>`
                                        
                                        .. attribute:: implicit_deny
                                        
                                        	Implicit deny
                                        	**type**\:  :py:class:`ImplicitDeny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit, self).__init__()

                                            self.yang_name = "interface-acl-implicit"
                                            self.yang_parent_name = "implicit-acl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("implicit-ndna-permit", ("implicit_ndna_permit", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit)), ("implicit-ndns-permit", ("implicit_ndns_permit", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit)), ("implicit-deny", ("implicit_deny", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny))])
                                            self._leafs = OrderedDict()

                                            self.implicit_ndna_permit = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit()
                                            self.implicit_ndna_permit.parent = self
                                            self._children_name_map["implicit_ndna_permit"] = "implicit-ndna-permit"

                                            self.implicit_ndns_permit = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit()
                                            self.implicit_ndns_permit.parent = self
                                            self._children_name_map["implicit_ndns_permit"] = "implicit-ndns-permit"

                                            self.implicit_deny = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny()
                                            self.implicit_deny.parent = self
                                            self._children_name_map["implicit_deny"] = "implicit-deny"
                                            self._segment_path = lambda: "interface-acl-implicit"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit, [], name, value)


                                        class ImplicitNdnaPermit(Entity):
                                            """
                                            Implicit NDNA permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit, self).__init__()

                                                self.yang_name = "implicit-ndna-permit"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndna-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                        class ImplicitNdnsPermit(Entity):
                                            """
                                            Implicit NDNS permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit, self).__init__()

                                                self.yang_name = "implicit-ndns-permit"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndns-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                        class ImplicitDeny(Entity):
                                            """
                                            Implicit deny
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny, self).__init__()

                                                self.yang_name = "implicit-deny"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-deny"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                            class SequenceDetails(Entity):
                                """
                                Table of all sequence numbers per ACL
                                
                                .. attribute:: sequence_detail
                                
                                	Detail ACL information
                                	**type**\: list of  		 :py:class:`SequenceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails, self).__init__()

                                    self.yang_name = "sequence-details"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sequence-detail", ("sequence_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail))])
                                    self._leafs = OrderedDict()

                                    self.sequence_detail = YList(self)
                                    self._segment_path = lambda: "sequence-details"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails, [], name, value)


                                class SequenceDetail(Entity):
                                    """
                                    Detail ACL information
                                    
                                    .. attribute:: sequence_number  (key)
                                    
                                    	Detail ACL information for a particular sequence
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: common_acl_detail
                                    
                                    	Common ACL detail information across Slices
                                    	**type**\: list of  		 :py:class:`CommonAclDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail>`
                                    
                                    .. attribute:: interface_acl_detail
                                    
                                    	Interface ACL detail information across Slices
                                    	**type**\: list of  		 :py:class:`InterfaceAclDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail, self).__init__()

                                        self.yang_name = "sequence-detail"
                                        self.yang_parent_name = "sequence-details"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['sequence_number']
                                        self._child_classes = OrderedDict([("common-acl-detail", ("common_acl_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail)), ("interface-acl-detail", ("interface_acl_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail))])
                                        self._leafs = OrderedDict([
                                            ('sequence_number', YLeaf(YType.int32, 'sequence-number')),
                                        ])
                                        self.sequence_number = None

                                        self.common_acl_detail = YList(self)
                                        self.interface_acl_detail = YList(self)
                                        self._segment_path = lambda: "sequence-detail" + "[sequence-number='" + str(self.sequence_number) + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail, ['sequence_number'], name, value)


                                    class CommonAclDetail(Entity):
                                        """
                                        Common ACL detail information across Slices
                                        
                                        .. attribute:: ace_brief
                                        
                                        	ACE brief information
                                        	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief>`
                                        
                                        .. attribute:: ace_detail
                                        
                                        	ACE detail information
                                        	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail, self).__init__()

                                            self.yang_name = "common-acl-detail"
                                            self.yang_parent_name = "sequence-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail))])
                                            self._leafs = OrderedDict()

                                            self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief()
                                            self.ace_brief.parent = self
                                            self._children_name_map["ace_brief"] = "ace-brief"

                                            self.ace_detail = YList(self)
                                            self._segment_path = lambda: "common-acl-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail, [], name, value)


                                        class AceBrief(Entity):
                                            """
                                            ACE brief information
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress>`
                                            
                                            .. attribute:: grant
                                            
                                            	Either permit or deny
                                            	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                            
                                            .. attribute:: logging_enabled
                                            
                                            	Logging enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: per_ace_icmp_enabled
                                            
                                            	Per ACE ICMP enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: next_hop_enabled
                                            
                                            	Next hop enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: default_next_hop_enabled
                                            
                                            	Default next hop enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: total_tcam_entries
                                            
                                            	Number of TCAM entries
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: hits
                                            
                                            	Number of TCAM hits
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: npu_id
                                            
                                            	NPU Id
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief, self).__init__()

                                                self.yang_name = "ace-brief"
                                                self.yang_parent_name = "common-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress))])
                                                self._leafs = OrderedDict([
                                                    ('grant', YLeaf(YType.enumeration, 'grant')),
                                                    ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                    ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                    ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                    ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                    ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                    ('hits', YLeaf(YType.uint64, 'hits')),
                                                    ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                ])
                                                self.grant = None
                                                self.logging_enabled = None
                                                self.per_ace_icmp_enabled = None
                                                self.next_hop_enabled = None
                                                self.default_next_hop_enabled = None
                                                self.total_tcam_entries = None
                                                self.hits = None
                                                self.npu_id = None

                                                self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress()
                                                self.next_hop_address.parent = self
                                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                                self._segment_path = lambda: "ace-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                            class NextHopAddress(Entity):
                                                """
                                                Next hop address
                                                
                                                .. attribute:: address_type
                                                
                                                	AddressType
                                                	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress, self).__init__()

                                                    self.yang_name = "next-hop-address"
                                                    self.yang_parent_name = "ace-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                    ])
                                                    self.address_type = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "next-hop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                        class AceDetail(Entity):
                                            """
                                            ACE detail information
                                            
                                            .. attribute:: ipv4tcam
                                            
                                            	IPv4 TCAM entries
                                            	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam>`
                                            
                                            .. attribute:: ipv6tcam
                                            
                                            	IPv6 TCAM entries
                                            	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam>`
                                            
                                            .. attribute:: entry_id
                                            
                                            	Entry ID
                                            	**type**\: int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail, self).__init__()

                                                self.yang_name = "ace-detail"
                                                self.yang_parent_name = "common-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam))])
                                                self._leafs = OrderedDict([
                                                    ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                ])
                                                self.entry_id = None

                                                self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam()
                                                self.ipv4tcam.parent = self
                                                self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam()
                                                self.ipv6tcam.parent = self
                                                self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                self._segment_path = lambda: "ace-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail, ['entry_id'], name, value)


                                            class Ipv4tcam(Entity):
                                                """
                                                IPv4 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam, self).__init__()

                                                    self.yang_name = "ipv4tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry))])
                                                    self._leafs = OrderedDict()

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._segment_path = lambda: "ipv4tcam"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam, [], name, value)


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Pfilter IPv4 TCAM value
                                                    	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	Pfilter IPv4 TCAM mask
                                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	Pfilter IPv4 TCAM result
                                                    	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv4tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                        self._leafs = OrderedDict()

                                                        self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"

                                                        self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"

                                                        self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                    class Value(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM value
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM mask
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM result
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                            class Ipv6tcam(Entity):
                                                """
                                                IPv6 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam, self).__init__()

                                                    self.yang_name = "ipv6tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry))])
                                                    self._leafs = OrderedDict()

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._segment_path = lambda: "ipv6tcam"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam, [], name, value)


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: value
                                                    
                                                    	IPv6 TCAM value
                                                    	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	IPv6 TCAM mask
                                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	IPv6 TCAM result
                                                    	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: source_address
                                                    
                                                    	Source address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: source_address_mask
                                                    
                                                    	Source address mask
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address
                                                    
                                                    	Destination address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address_mask
                                                    
                                                    	Destination address mask
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv6tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                        self._leafs = OrderedDict([
                                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                                            ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                            ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                            ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                        ])
                                                        self.source_address = None
                                                        self.source_address_mask = None
                                                        self.destination_address = None
                                                        self.destination_address_mask = None

                                                        self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"

                                                        self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"

                                                        self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        IPv6 TCAM value
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        IPv6 TCAM mask
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        IPv6 TCAM result
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                    class InterfaceAclDetail(Entity):
                                        """
                                        Interface ACL detail information across Slices
                                        
                                        .. attribute:: ace_brief
                                        
                                        	ACE brief information
                                        	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief>`
                                        
                                        .. attribute:: ace_detail
                                        
                                        	ACE detail information
                                        	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail, self).__init__()

                                            self.yang_name = "interface-acl-detail"
                                            self.yang_parent_name = "sequence-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail))])
                                            self._leafs = OrderedDict()

                                            self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief()
                                            self.ace_brief.parent = self
                                            self._children_name_map["ace_brief"] = "ace-brief"

                                            self.ace_detail = YList(self)
                                            self._segment_path = lambda: "interface-acl-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail, [], name, value)


                                        class AceBrief(Entity):
                                            """
                                            ACE brief information
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress>`
                                            
                                            .. attribute:: grant
                                            
                                            	Either permit or deny
                                            	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                            
                                            .. attribute:: logging_enabled
                                            
                                            	Logging enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: per_ace_icmp_enabled
                                            
                                            	Per ACE ICMP enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: next_hop_enabled
                                            
                                            	Next hop enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: default_next_hop_enabled
                                            
                                            	Default next hop enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: total_tcam_entries
                                            
                                            	Number of TCAM entries
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: hits
                                            
                                            	Number of TCAM hits
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: npu_id
                                            
                                            	NPU Id
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief, self).__init__()

                                                self.yang_name = "ace-brief"
                                                self.yang_parent_name = "interface-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress))])
                                                self._leafs = OrderedDict([
                                                    ('grant', YLeaf(YType.enumeration, 'grant')),
                                                    ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                    ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                    ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                    ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                    ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                    ('hits', YLeaf(YType.uint64, 'hits')),
                                                    ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                ])
                                                self.grant = None
                                                self.logging_enabled = None
                                                self.per_ace_icmp_enabled = None
                                                self.next_hop_enabled = None
                                                self.default_next_hop_enabled = None
                                                self.total_tcam_entries = None
                                                self.hits = None
                                                self.npu_id = None

                                                self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress()
                                                self.next_hop_address.parent = self
                                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                                self._segment_path = lambda: "ace-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                            class NextHopAddress(Entity):
                                                """
                                                Next hop address
                                                
                                                .. attribute:: address_type
                                                
                                                	AddressType
                                                	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress, self).__init__()

                                                    self.yang_name = "next-hop-address"
                                                    self.yang_parent_name = "ace-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                    ])
                                                    self.address_type = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "next-hop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                        class AceDetail(Entity):
                                            """
                                            ACE detail information
                                            
                                            .. attribute:: ipv4tcam
                                            
                                            	IPv4 TCAM entries
                                            	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam>`
                                            
                                            .. attribute:: ipv6tcam
                                            
                                            	IPv6 TCAM entries
                                            	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam>`
                                            
                                            .. attribute:: entry_id
                                            
                                            	Entry ID
                                            	**type**\: int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail, self).__init__()

                                                self.yang_name = "ace-detail"
                                                self.yang_parent_name = "interface-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam))])
                                                self._leafs = OrderedDict([
                                                    ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                ])
                                                self.entry_id = None

                                                self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam()
                                                self.ipv4tcam.parent = self
                                                self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam()
                                                self.ipv6tcam.parent = self
                                                self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                self._segment_path = lambda: "ace-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail, ['entry_id'], name, value)


                                            class Ipv4tcam(Entity):
                                                """
                                                IPv4 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam, self).__init__()

                                                    self.yang_name = "ipv4tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry))])
                                                    self._leafs = OrderedDict()

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._segment_path = lambda: "ipv4tcam"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam, [], name, value)


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Pfilter IPv4 TCAM value
                                                    	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	Pfilter IPv4 TCAM mask
                                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	Pfilter IPv4 TCAM result
                                                    	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv4tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                        self._leafs = OrderedDict()

                                                        self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"

                                                        self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"

                                                        self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                    class Value(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM value
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM mask
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM result
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                            class Ipv6tcam(Entity):
                                                """
                                                IPv6 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam, self).__init__()

                                                    self.yang_name = "ipv6tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry))])
                                                    self._leafs = OrderedDict()

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._segment_path = lambda: "ipv6tcam"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam, [], name, value)


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: value
                                                    
                                                    	IPv6 TCAM value
                                                    	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	IPv6 TCAM mask
                                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	IPv6 TCAM result
                                                    	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: source_address
                                                    
                                                    	Source address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: source_address_mask
                                                    
                                                    	Source address mask
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address
                                                    
                                                    	Destination address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address_mask
                                                    
                                                    	Destination address mask
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv6tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                        self._leafs = OrderedDict([
                                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                                            ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                            ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                            ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                        ])
                                                        self.source_address = None
                                                        self.source_address_mask = None
                                                        self.destination_address = None
                                                        self.destination_address_mask = None

                                                        self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"

                                                        self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"

                                                        self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        IPv6 TCAM value
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        IPv6 TCAM mask
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        IPv6 TCAM result
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                            class SequenceBriefs(Entity):
                                """
                                Table of all sequence numbers per ACL
                                
                                .. attribute:: sequence_brief
                                
                                	Detail ACL information
                                	**type**\: list of  		 :py:class:`SequenceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs, self).__init__()

                                    self.yang_name = "sequence-briefs"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sequence-brief", ("sequence_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief))])
                                    self._leafs = OrderedDict()

                                    self.sequence_brief = YList(self)
                                    self._segment_path = lambda: "sequence-briefs"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs, [], name, value)


                                class SequenceBrief(Entity):
                                    """
                                    Detail ACL information
                                    
                                    .. attribute:: sequence_number  (key)
                                    
                                    	Brief ACL information for a particular sequence
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: common_acl
                                    
                                    	Common ACL information across Slices
                                    	**type**\: list of  		 :py:class:`CommonAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl>`
                                    
                                    .. attribute:: interface_acl
                                    
                                    	Interface ACL information across Slices
                                    	**type**\: list of  		 :py:class:`InterfaceAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief, self).__init__()

                                        self.yang_name = "sequence-brief"
                                        self.yang_parent_name = "sequence-briefs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['sequence_number']
                                        self._child_classes = OrderedDict([("common-acl", ("common_acl", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl)), ("interface-acl", ("interface_acl", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl))])
                                        self._leafs = OrderedDict([
                                            ('sequence_number', YLeaf(YType.int32, 'sequence-number')),
                                        ])
                                        self.sequence_number = None

                                        self.common_acl = YList(self)
                                        self.interface_acl = YList(self)
                                        self._segment_path = lambda: "sequence-brief" + "[sequence-number='" + str(self.sequence_number) + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief, ['sequence_number'], name, value)


                                    class CommonAcl(Entity):
                                        """
                                        Common ACL information across Slices
                                        
                                        .. attribute:: next_hop_address
                                        
                                        	Next hop address
                                        	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress>`
                                        
                                        .. attribute:: grant
                                        
                                        	Either permit or deny
                                        	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                        
                                        .. attribute:: logging_enabled
                                        
                                        	Logging enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: per_ace_icmp_enabled
                                        
                                        	Per ACE ICMP enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: next_hop_enabled
                                        
                                        	Next hop enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: default_next_hop_enabled
                                        
                                        	Default next hop enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: total_tcam_entries
                                        
                                        	Number of TCAM entries
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: hits
                                        
                                        	Number of TCAM hits
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: npu_id
                                        
                                        	NPU Id
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl, self).__init__()

                                            self.yang_name = "common-acl"
                                            self.yang_parent_name = "sequence-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress))])
                                            self._leafs = OrderedDict([
                                                ('grant', YLeaf(YType.enumeration, 'grant')),
                                                ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                ('hits', YLeaf(YType.uint64, 'hits')),
                                                ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                            ])
                                            self.grant = None
                                            self.logging_enabled = None
                                            self.per_ace_icmp_enabled = None
                                            self.next_hop_enabled = None
                                            self.default_next_hop_enabled = None
                                            self.total_tcam_entries = None
                                            self.hits = None
                                            self.npu_id = None

                                            self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                            self._segment_path = lambda: "common-acl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                        class NextHopAddress(Entity):
                                            """
                                            Next hop address
                                            
                                            .. attribute:: address_type
                                            
                                            	AddressType
                                            	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress, self).__init__()

                                                self.yang_name = "next-hop-address"
                                                self.yang_parent_name = "common-acl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                ])
                                                self.address_type = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "next-hop-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                    class InterfaceAcl(Entity):
                                        """
                                        Interface ACL information across Slices
                                        
                                        .. attribute:: next_hop_address
                                        
                                        	Next hop address
                                        	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress>`
                                        
                                        .. attribute:: grant
                                        
                                        	Either permit or deny
                                        	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                        
                                        .. attribute:: logging_enabled
                                        
                                        	Logging enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: per_ace_icmp_enabled
                                        
                                        	Per ACE ICMP enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: next_hop_enabled
                                        
                                        	Next hop enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: default_next_hop_enabled
                                        
                                        	Default next hop enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: total_tcam_entries
                                        
                                        	Number of TCAM entries
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: hits
                                        
                                        	Number of TCAM hits
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: npu_id
                                        
                                        	NPU Id
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl, self).__init__()

                                            self.yang_name = "interface-acl"
                                            self.yang_parent_name = "sequence-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress))])
                                            self._leafs = OrderedDict([
                                                ('grant', YLeaf(YType.enumeration, 'grant')),
                                                ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                ('hits', YLeaf(YType.uint64, 'hits')),
                                                ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                            ])
                                            self.grant = None
                                            self.logging_enabled = None
                                            self.per_ace_icmp_enabled = None
                                            self.next_hop_enabled = None
                                            self.default_next_hop_enabled = None
                                            self.total_tcam_entries = None
                                            self.hits = None
                                            self.npu_id = None

                                            self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                            self._segment_path = lambda: "interface-acl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                        class NextHopAddress(Entity):
                                            """
                                            Next hop address
                                            
                                            .. attribute:: address_type
                                            
                                            	AddressType
                                            	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress, self).__init__()

                                                self.yang_name = "next-hop-address"
                                                self.yang_parent_name = "interface-acl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                ])
                                                self.address_type = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "next-hop-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                class Ipv6(Entity):
                    """
                    Accesslist version IPv6
                    
                    .. attribute:: accesses
                    
                    	Table for access lists
                    	**type**\:  :py:class:`Accesses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses>`
                    
                    

                    """

                    _prefix = 'ncs6k-acl-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "ingress"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("accesses", ("accesses", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses))])
                        self._leafs = OrderedDict()

                        self.accesses = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses()
                        self.accesses.parent = self
                        self._children_name_map["accesses"] = "accesses"
                        self._segment_path = lambda: "ipv6"

                    def __setattr__(self, name, value):
                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6, [], name, value)


                    class Accesses(Entity):
                        """
                        Table for access lists
                        
                        .. attribute:: access
                        
                        	List of ACLs
                        	**type**\: list of  		 :py:class:`Access <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access>`
                        
                        

                        """

                        _prefix = 'ncs6k-acl-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses, self).__init__()

                            self.yang_name = "accesses"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("access", ("access", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access))])
                            self._leafs = OrderedDict()

                            self.access = YList(self)
                            self._segment_path = lambda: "accesses"

                        def __setattr__(self, name, value):
                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses, [], name, value)


                        class Access(Entity):
                            """
                            List of ACLs
                            
                            .. attribute:: access_list_name  (key)
                            
                            	Name of the access list
                            	**type**\: str
                            
                            .. attribute:: implicit
                            
                            	Implicit ACL information
                            	**type**\:  :py:class:`Implicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit>`
                            
                            .. attribute:: sequence_details
                            
                            	Table of all sequence numbers per ACL
                            	**type**\:  :py:class:`SequenceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails>`
                            
                            .. attribute:: sequence_briefs
                            
                            	Table of all sequence numbers per ACL
                            	**type**\:  :py:class:`SequenceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs>`
                            
                            

                            """

                            _prefix = 'ncs6k-acl-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access, self).__init__()

                                self.yang_name = "access"
                                self.yang_parent_name = "accesses"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['access_list_name']
                                self._child_classes = OrderedDict([("implicit", ("implicit", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit)), ("sequence-details", ("sequence_details", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails)), ("sequence-briefs", ("sequence_briefs", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs))])
                                self._leafs = OrderedDict([
                                    ('access_list_name', YLeaf(YType.str, 'access-list-name')),
                                ])
                                self.access_list_name = None

                                self.implicit = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit()
                                self.implicit.parent = self
                                self._children_name_map["implicit"] = "implicit"

                                self.sequence_details = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails()
                                self.sequence_details.parent = self
                                self._children_name_map["sequence_details"] = "sequence-details"

                                self.sequence_briefs = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs()
                                self.sequence_briefs.parent = self
                                self._children_name_map["sequence_briefs"] = "sequence-briefs"
                                self._segment_path = lambda: "access" + "[access-list-name='" + str(self.access_list_name) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access, ['access_list_name'], name, value)


                            class Implicit(Entity):
                                """
                                Implicit ACL information
                                
                                .. attribute:: implicit_acl
                                
                                	Implicit ACL Entries across Slices
                                	**type**\: list of  		 :py:class:`ImplicitAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit, self).__init__()

                                    self.yang_name = "implicit"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("implicit-acl", ("implicit_acl", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl))])
                                    self._leafs = OrderedDict()

                                    self.implicit_acl = YList(self)
                                    self._segment_path = lambda: "implicit"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit, [], name, value)


                                class ImplicitAcl(Entity):
                                    """
                                    Implicit ACL Entries across Slices
                                    
                                    .. attribute:: common_acl_implicit
                                    
                                    	Common ACL Implicit Entries
                                    	**type**\:  :py:class:`CommonAclImplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit>`
                                    
                                    .. attribute:: interface_acl_implicit
                                    
                                    	Interface ACL Implicit Entries
                                    	**type**\:  :py:class:`InterfaceAclImplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl, self).__init__()

                                        self.yang_name = "implicit-acl"
                                        self.yang_parent_name = "implicit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("common-acl-implicit", ("common_acl_implicit", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit)), ("interface-acl-implicit", ("interface_acl_implicit", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit))])
                                        self._leafs = OrderedDict()

                                        self.common_acl_implicit = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit()
                                        self.common_acl_implicit.parent = self
                                        self._children_name_map["common_acl_implicit"] = "common-acl-implicit"

                                        self.interface_acl_implicit = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit()
                                        self.interface_acl_implicit.parent = self
                                        self._children_name_map["interface_acl_implicit"] = "interface-acl-implicit"
                                        self._segment_path = lambda: "implicit-acl"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl, [], name, value)


                                    class CommonAclImplicit(Entity):
                                        """
                                        Common ACL Implicit Entries
                                        
                                        .. attribute:: implicit_ndna_permit
                                        
                                        	Implicit NDNA permit
                                        	**type**\:  :py:class:`ImplicitNdnaPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit>`
                                        
                                        .. attribute:: implicit_ndns_permit
                                        
                                        	Implicit NDNS permit
                                        	**type**\:  :py:class:`ImplicitNdnsPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit>`
                                        
                                        .. attribute:: implicit_deny
                                        
                                        	Implicit deny
                                        	**type**\:  :py:class:`ImplicitDeny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit, self).__init__()

                                            self.yang_name = "common-acl-implicit"
                                            self.yang_parent_name = "implicit-acl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("implicit-ndna-permit", ("implicit_ndna_permit", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit)), ("implicit-ndns-permit", ("implicit_ndns_permit", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit)), ("implicit-deny", ("implicit_deny", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny))])
                                            self._leafs = OrderedDict()

                                            self.implicit_ndna_permit = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit()
                                            self.implicit_ndna_permit.parent = self
                                            self._children_name_map["implicit_ndna_permit"] = "implicit-ndna-permit"

                                            self.implicit_ndns_permit = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit()
                                            self.implicit_ndns_permit.parent = self
                                            self._children_name_map["implicit_ndns_permit"] = "implicit-ndns-permit"

                                            self.implicit_deny = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny()
                                            self.implicit_deny.parent = self
                                            self._children_name_map["implicit_deny"] = "implicit-deny"
                                            self._segment_path = lambda: "common-acl-implicit"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit, [], name, value)


                                        class ImplicitNdnaPermit(Entity):
                                            """
                                            Implicit NDNA permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit, self).__init__()

                                                self.yang_name = "implicit-ndna-permit"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndna-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                        class ImplicitNdnsPermit(Entity):
                                            """
                                            Implicit NDNS permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit, self).__init__()

                                                self.yang_name = "implicit-ndns-permit"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndns-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                        class ImplicitDeny(Entity):
                                            """
                                            Implicit deny
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny, self).__init__()

                                                self.yang_name = "implicit-deny"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-deny"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                    class InterfaceAclImplicit(Entity):
                                        """
                                        Interface ACL Implicit Entries
                                        
                                        .. attribute:: implicit_ndna_permit
                                        
                                        	Implicit NDNA permit
                                        	**type**\:  :py:class:`ImplicitNdnaPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit>`
                                        
                                        .. attribute:: implicit_ndns_permit
                                        
                                        	Implicit NDNS permit
                                        	**type**\:  :py:class:`ImplicitNdnsPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit>`
                                        
                                        .. attribute:: implicit_deny
                                        
                                        	Implicit deny
                                        	**type**\:  :py:class:`ImplicitDeny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit, self).__init__()

                                            self.yang_name = "interface-acl-implicit"
                                            self.yang_parent_name = "implicit-acl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("implicit-ndna-permit", ("implicit_ndna_permit", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit)), ("implicit-ndns-permit", ("implicit_ndns_permit", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit)), ("implicit-deny", ("implicit_deny", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny))])
                                            self._leafs = OrderedDict()

                                            self.implicit_ndna_permit = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit()
                                            self.implicit_ndna_permit.parent = self
                                            self._children_name_map["implicit_ndna_permit"] = "implicit-ndna-permit"

                                            self.implicit_ndns_permit = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit()
                                            self.implicit_ndns_permit.parent = self
                                            self._children_name_map["implicit_ndns_permit"] = "implicit-ndns-permit"

                                            self.implicit_deny = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny()
                                            self.implicit_deny.parent = self
                                            self._children_name_map["implicit_deny"] = "implicit-deny"
                                            self._segment_path = lambda: "interface-acl-implicit"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit, [], name, value)


                                        class ImplicitNdnaPermit(Entity):
                                            """
                                            Implicit NDNA permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit, self).__init__()

                                                self.yang_name = "implicit-ndna-permit"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndna-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                        class ImplicitNdnsPermit(Entity):
                                            """
                                            Implicit NDNS permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit, self).__init__()

                                                self.yang_name = "implicit-ndns-permit"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndns-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                        class ImplicitDeny(Entity):
                                            """
                                            Implicit deny
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny, self).__init__()

                                                self.yang_name = "implicit-deny"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail))])
                                                self._leafs = OrderedDict()

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-deny"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('grant', YLeaf(YType.enumeration, 'grant')),
                                                        ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                        ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                        ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                        ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                        ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                        ('hits', YLeaf(YType.uint64, 'hits')),
                                                        ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                    ])
                                                    self.grant = None
                                                    self.logging_enabled = None
                                                    self.per_ace_icmp_enabled = None
                                                    self.next_hop_enabled = None
                                                    self.default_next_hop_enabled = None
                                                    self.total_tcam_entries = None
                                                    self.hits = None
                                                    self.npu_id = None

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                        ])
                                                        self.address_type = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam>`
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam))])
                                                    self._leafs = OrderedDict([
                                                        ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                    ])
                                                    self.entry_id = None

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail, ['entry_id'], name, value)


                                                class Ipv4tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv4tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict()

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                    ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                    ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                    ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                    ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.source_address = None
                                                                self.protocol = None
                                                                self.fragment = None
                                                                self.dscp = None
                                                                self.ttl = None
                                                                self.layer4_source_port = None
                                                                self.destination_address = None
                                                                self.layer4_destination_port = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                class Ipv6tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry))])
                                                        self._leafs = OrderedDict()

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._segment_path = lambda: "ipv6tcam"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam, [], name, value)


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                            self._leafs = OrderedDict([
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                            ])
                                                            self.source_address = None
                                                            self.source_address_mask = None
                                                            self.destination_address = None
                                                            self.destination_address_mask = None

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                                self._leafs = OrderedDict([
                                                                    ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                    ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                    ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                    ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                    ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                    ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                    ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                    ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                    ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                    ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                                    ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                                ])
                                                                self.acl_id = None
                                                                self.protocol = None
                                                                self.layer4_source_port = None
                                                                self.layer4_destination_port = None
                                                                self.source_range_id = None
                                                                self.destination_range_id = None
                                                                self.destination_header = None
                                                                self.receive_transition_gap_header = None
                                                                self.authentication_header = None
                                                                self.fragment = None
                                                                self.tos = None
                                                                self.packet_length_range = None

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                        ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                        ('push', YLeaf(YType.uint8, 'push')),
                                                                        ('reset', YLeaf(YType.uint8, 'reset')),
                                                                        ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                        ('finish', YLeaf(YType.uint8, 'finish')),
                                                                    ])
                                                                    self.urgent = None
                                                                    self.acknowledge = None
                                                                    self.push = None
                                                                    self.reset = None
                                                                    self.synchronization = None
                                                                    self.finish = None
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                            class SequenceDetails(Entity):
                                """
                                Table of all sequence numbers per ACL
                                
                                .. attribute:: sequence_detail
                                
                                	Detail ACL information
                                	**type**\: list of  		 :py:class:`SequenceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails, self).__init__()

                                    self.yang_name = "sequence-details"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sequence-detail", ("sequence_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail))])
                                    self._leafs = OrderedDict()

                                    self.sequence_detail = YList(self)
                                    self._segment_path = lambda: "sequence-details"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails, [], name, value)


                                class SequenceDetail(Entity):
                                    """
                                    Detail ACL information
                                    
                                    .. attribute:: sequence_number  (key)
                                    
                                    	Detail ACL information for a particular sequence
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: common_acl_detail
                                    
                                    	Common ACL detail information across Slices
                                    	**type**\: list of  		 :py:class:`CommonAclDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail>`
                                    
                                    .. attribute:: interface_acl_detail
                                    
                                    	Interface ACL detail information across Slices
                                    	**type**\: list of  		 :py:class:`InterfaceAclDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail, self).__init__()

                                        self.yang_name = "sequence-detail"
                                        self.yang_parent_name = "sequence-details"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['sequence_number']
                                        self._child_classes = OrderedDict([("common-acl-detail", ("common_acl_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail)), ("interface-acl-detail", ("interface_acl_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail))])
                                        self._leafs = OrderedDict([
                                            ('sequence_number', YLeaf(YType.int32, 'sequence-number')),
                                        ])
                                        self.sequence_number = None

                                        self.common_acl_detail = YList(self)
                                        self.interface_acl_detail = YList(self)
                                        self._segment_path = lambda: "sequence-detail" + "[sequence-number='" + str(self.sequence_number) + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail, ['sequence_number'], name, value)


                                    class CommonAclDetail(Entity):
                                        """
                                        Common ACL detail information across Slices
                                        
                                        .. attribute:: ace_brief
                                        
                                        	ACE brief information
                                        	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief>`
                                        
                                        .. attribute:: ace_detail
                                        
                                        	ACE detail information
                                        	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail, self).__init__()

                                            self.yang_name = "common-acl-detail"
                                            self.yang_parent_name = "sequence-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail))])
                                            self._leafs = OrderedDict()

                                            self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief()
                                            self.ace_brief.parent = self
                                            self._children_name_map["ace_brief"] = "ace-brief"

                                            self.ace_detail = YList(self)
                                            self._segment_path = lambda: "common-acl-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail, [], name, value)


                                        class AceBrief(Entity):
                                            """
                                            ACE brief information
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress>`
                                            
                                            .. attribute:: grant
                                            
                                            	Either permit or deny
                                            	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                            
                                            .. attribute:: logging_enabled
                                            
                                            	Logging enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: per_ace_icmp_enabled
                                            
                                            	Per ACE ICMP enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: next_hop_enabled
                                            
                                            	Next hop enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: default_next_hop_enabled
                                            
                                            	Default next hop enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: total_tcam_entries
                                            
                                            	Number of TCAM entries
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: hits
                                            
                                            	Number of TCAM hits
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: npu_id
                                            
                                            	NPU Id
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief, self).__init__()

                                                self.yang_name = "ace-brief"
                                                self.yang_parent_name = "common-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress))])
                                                self._leafs = OrderedDict([
                                                    ('grant', YLeaf(YType.enumeration, 'grant')),
                                                    ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                    ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                    ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                    ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                    ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                    ('hits', YLeaf(YType.uint64, 'hits')),
                                                    ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                ])
                                                self.grant = None
                                                self.logging_enabled = None
                                                self.per_ace_icmp_enabled = None
                                                self.next_hop_enabled = None
                                                self.default_next_hop_enabled = None
                                                self.total_tcam_entries = None
                                                self.hits = None
                                                self.npu_id = None

                                                self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress()
                                                self.next_hop_address.parent = self
                                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                                self._segment_path = lambda: "ace-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                            class NextHopAddress(Entity):
                                                """
                                                Next hop address
                                                
                                                .. attribute:: address_type
                                                
                                                	AddressType
                                                	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress, self).__init__()

                                                    self.yang_name = "next-hop-address"
                                                    self.yang_parent_name = "ace-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                    ])
                                                    self.address_type = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "next-hop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                        class AceDetail(Entity):
                                            """
                                            ACE detail information
                                            
                                            .. attribute:: ipv4tcam
                                            
                                            	IPv4 TCAM entries
                                            	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam>`
                                            
                                            .. attribute:: ipv6tcam
                                            
                                            	IPv6 TCAM entries
                                            	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam>`
                                            
                                            .. attribute:: entry_id
                                            
                                            	Entry ID
                                            	**type**\: int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail, self).__init__()

                                                self.yang_name = "ace-detail"
                                                self.yang_parent_name = "common-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam))])
                                                self._leafs = OrderedDict([
                                                    ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                ])
                                                self.entry_id = None

                                                self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam()
                                                self.ipv4tcam.parent = self
                                                self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam()
                                                self.ipv6tcam.parent = self
                                                self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                self._segment_path = lambda: "ace-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail, ['entry_id'], name, value)


                                            class Ipv4tcam(Entity):
                                                """
                                                IPv4 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam, self).__init__()

                                                    self.yang_name = "ipv4tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry))])
                                                    self._leafs = OrderedDict()

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._segment_path = lambda: "ipv4tcam"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam, [], name, value)


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Pfilter IPv4 TCAM value
                                                    	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	Pfilter IPv4 TCAM mask
                                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	Pfilter IPv4 TCAM result
                                                    	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv4tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                        self._leafs = OrderedDict()

                                                        self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"

                                                        self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"

                                                        self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                    class Value(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM value
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM mask
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM result
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                            class Ipv6tcam(Entity):
                                                """
                                                IPv6 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam, self).__init__()

                                                    self.yang_name = "ipv6tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry))])
                                                    self._leafs = OrderedDict()

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._segment_path = lambda: "ipv6tcam"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam, [], name, value)


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: value
                                                    
                                                    	IPv6 TCAM value
                                                    	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	IPv6 TCAM mask
                                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	IPv6 TCAM result
                                                    	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: source_address
                                                    
                                                    	Source address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: source_address_mask
                                                    
                                                    	Source address mask
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address
                                                    
                                                    	Destination address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address_mask
                                                    
                                                    	Destination address mask
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv6tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                        self._leafs = OrderedDict([
                                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                                            ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                            ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                            ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                        ])
                                                        self.source_address = None
                                                        self.source_address_mask = None
                                                        self.destination_address = None
                                                        self.destination_address_mask = None

                                                        self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"

                                                        self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"

                                                        self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        IPv6 TCAM value
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        IPv6 TCAM mask
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        IPv6 TCAM result
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                    class InterfaceAclDetail(Entity):
                                        """
                                        Interface ACL detail information across Slices
                                        
                                        .. attribute:: ace_brief
                                        
                                        	ACE brief information
                                        	**type**\:  :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief>`
                                        
                                        .. attribute:: ace_detail
                                        
                                        	ACE detail information
                                        	**type**\: list of  		 :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail, self).__init__()

                                            self.yang_name = "interface-acl-detail"
                                            self.yang_parent_name = "sequence-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ace-brief", ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief)), ("ace-detail", ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail))])
                                            self._leafs = OrderedDict()

                                            self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief()
                                            self.ace_brief.parent = self
                                            self._children_name_map["ace_brief"] = "ace-brief"

                                            self.ace_detail = YList(self)
                                            self._segment_path = lambda: "interface-acl-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail, [], name, value)


                                        class AceBrief(Entity):
                                            """
                                            ACE brief information
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress>`
                                            
                                            .. attribute:: grant
                                            
                                            	Either permit or deny
                                            	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                            
                                            .. attribute:: logging_enabled
                                            
                                            	Logging enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: per_ace_icmp_enabled
                                            
                                            	Per ACE ICMP enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: next_hop_enabled
                                            
                                            	Next hop enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: default_next_hop_enabled
                                            
                                            	Default next hop enabled/disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: total_tcam_entries
                                            
                                            	Number of TCAM entries
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: hits
                                            
                                            	Number of TCAM hits
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: npu_id
                                            
                                            	NPU Id
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief, self).__init__()

                                                self.yang_name = "ace-brief"
                                                self.yang_parent_name = "interface-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress))])
                                                self._leafs = OrderedDict([
                                                    ('grant', YLeaf(YType.enumeration, 'grant')),
                                                    ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                    ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                    ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                    ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                    ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                    ('hits', YLeaf(YType.uint64, 'hits')),
                                                    ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                                ])
                                                self.grant = None
                                                self.logging_enabled = None
                                                self.per_ace_icmp_enabled = None
                                                self.next_hop_enabled = None
                                                self.default_next_hop_enabled = None
                                                self.total_tcam_entries = None
                                                self.hits = None
                                                self.npu_id = None

                                                self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress()
                                                self.next_hop_address.parent = self
                                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                                self._segment_path = lambda: "ace-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                            class NextHopAddress(Entity):
                                                """
                                                Next hop address
                                                
                                                .. attribute:: address_type
                                                
                                                	AddressType
                                                	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress, self).__init__()

                                                    self.yang_name = "next-hop-address"
                                                    self.yang_parent_name = "ace-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                    ])
                                                    self.address_type = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "next-hop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                        class AceDetail(Entity):
                                            """
                                            ACE detail information
                                            
                                            .. attribute:: ipv4tcam
                                            
                                            	IPv4 TCAM entries
                                            	**type**\:  :py:class:`Ipv4tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam>`
                                            
                                            .. attribute:: ipv6tcam
                                            
                                            	IPv6 TCAM entries
                                            	**type**\:  :py:class:`Ipv6tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam>`
                                            
                                            .. attribute:: entry_id
                                            
                                            	Entry ID
                                            	**type**\: int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail, self).__init__()

                                                self.yang_name = "ace-detail"
                                                self.yang_parent_name = "interface-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ipv4tcam", ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam)), ("ipv6tcam", ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam))])
                                                self._leafs = OrderedDict([
                                                    ('entry_id', YLeaf(YType.int32, 'entry-id')),
                                                ])
                                                self.entry_id = None

                                                self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam()
                                                self.ipv4tcam.parent = self
                                                self._children_name_map["ipv4tcam"] = "ipv4tcam"

                                                self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam()
                                                self.ipv6tcam.parent = self
                                                self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                self._segment_path = lambda: "ace-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail, ['entry_id'], name, value)


                                            class Ipv4tcam(Entity):
                                                """
                                                IPv4 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam, self).__init__()

                                                    self.yang_name = "ipv4tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry))])
                                                    self._leafs = OrderedDict()

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._segment_path = lambda: "ipv4tcam"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam, [], name, value)


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Pfilter IPv4 TCAM value
                                                    	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value>`
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	Pfilter IPv4 TCAM mask
                                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	Pfilter IPv4 TCAM result
                                                    	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv4tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result))])
                                                        self._leafs = OrderedDict()

                                                        self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"

                                                        self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"

                                                        self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry, [], name, value)


                                                    class Value(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM value
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM mask
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM result
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('source_range_id', YLeaf(YType.uint16, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint16, 'destination-range-id')),
                                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('fragment', YLeaf(YType.uint16, 'fragment')),
                                                                ('dscp', YLeaf(YType.uint8, 'dscp')),
                                                                ('ttl', YLeaf(YType.uint32, 'ttl')),
                                                                ('layer4_source_port', YLeaf(YType.uint16, 'layer4-source-port')),
                                                                ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('packet_length_range', YLeaf(YType.uint8, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.source_address = None
                                                            self.protocol = None
                                                            self.fragment = None
                                                            self.dscp = None
                                                            self.ttl = None
                                                            self.layer4_source_port = None
                                                            self.destination_address = None
                                                            self.layer4_destination_port = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result, ['acl_id', 'source_range_id', 'destination_range_id', 'source_address', 'protocol', 'fragment', 'dscp', 'ttl', 'layer4_source_port', 'destination_address', 'layer4_destination_port', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                            class Ipv6tcam(Entity):
                                                """
                                                IPv6 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:  :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam, self).__init__()

                                                    self.yang_name = "ipv6tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tcam-entry", ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry))])
                                                    self._leafs = OrderedDict()

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._segment_path = lambda: "ipv6tcam"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam, [], name, value)


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: value
                                                    
                                                    	IPv6 TCAM value
                                                    	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value>`
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	IPv6 TCAM mask
                                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	IPv6 TCAM result
                                                    	**type**\:  :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: source_address
                                                    
                                                    	Source address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: source_address_mask
                                                    
                                                    	Source address mask
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address
                                                    
                                                    	Destination address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address_mask
                                                    
                                                    	Destination address mask
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv6tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("value", ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value)), ("mask", ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask)), ("result", ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result))])
                                                        self._leafs = OrderedDict([
                                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                                            ('source_address_mask', YLeaf(YType.str, 'source-address-mask')),
                                                            ('destination_address', YLeaf(YType.str, 'destination-address')),
                                                            ('destination_address_mask', YLeaf(YType.str, 'destination-address-mask')),
                                                        ])
                                                        self.source_address = None
                                                        self.source_address_mask = None
                                                        self.destination_address = None
                                                        self.destination_address_mask = None

                                                        self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"

                                                        self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"

                                                        self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry, ['source_address', 'source_address_mask', 'destination_address', 'destination_address_mask'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        IPv6 TCAM value
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Value.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        IPv6 TCAM mask
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Mask.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        IPv6 TCAM result
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:  :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("tcp-flags", ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags))])
                                                            self._leafs = OrderedDict([
                                                                ('acl_id', YLeaf(YType.uint16, 'acl-id')),
                                                                ('protocol', YLeaf(YType.uint8, 'protocol')),
                                                                ('layer4_source_port', YLeaf(YType.uint32, 'layer4-source-port')),
                                                                ('layer4_destination_port', YLeaf(YType.uint16, 'layer4-destination-port')),
                                                                ('source_range_id', YLeaf(YType.uint32, 'source-range-id')),
                                                                ('destination_range_id', YLeaf(YType.uint32, 'destination-range-id')),
                                                                ('destination_header', YLeaf(YType.uint8, 'destination-header')),
                                                                ('receive_transition_gap_header', YLeaf(YType.uint8, 'receive-transition-gap-header')),
                                                                ('authentication_header', YLeaf(YType.uint8, 'authentication-header')),
                                                                ('fragment', YLeaf(YType.uint8, 'fragment')),
                                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                                ('packet_length_range', YLeaf(YType.uint32, 'packet-length-range')),
                                                            ])
                                                            self.acl_id = None
                                                            self.protocol = None
                                                            self.layer4_source_port = None
                                                            self.layer4_destination_port = None
                                                            self.source_range_id = None
                                                            self.destination_range_id = None
                                                            self.destination_header = None
                                                            self.receive_transition_gap_header = None
                                                            self.authentication_header = None
                                                            self.fragment = None
                                                            self.tos = None
                                                            self.packet_length_range = None

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result, ['acl_id', 'protocol', 'layer4_source_port', 'layer4_destination_port', 'source_range_id', 'destination_range_id', 'destination_header', 'receive_transition_gap_header', 'authentication_header', 'fragment', 'tos', 'packet_length_range'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('urgent', YLeaf(YType.uint8, 'urgent')),
                                                                    ('acknowledge', YLeaf(YType.uint8, 'acknowledge')),
                                                                    ('push', YLeaf(YType.uint8, 'push')),
                                                                    ('reset', YLeaf(YType.uint8, 'reset')),
                                                                    ('synchronization', YLeaf(YType.uint8, 'synchronization')),
                                                                    ('finish', YLeaf(YType.uint8, 'finish')),
                                                                ])
                                                                self.urgent = None
                                                                self.acknowledge = None
                                                                self.push = None
                                                                self.reset = None
                                                                self.synchronization = None
                                                                self.finish = None
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6tcam.TcamEntry.Result.TcpFlags, ['urgent', 'acknowledge', 'push', 'reset', 'synchronization', 'finish'], name, value)


                            class SequenceBriefs(Entity):
                                """
                                Table of all sequence numbers per ACL
                                
                                .. attribute:: sequence_brief
                                
                                	Detail ACL information
                                	**type**\: list of  		 :py:class:`SequenceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs, self).__init__()

                                    self.yang_name = "sequence-briefs"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sequence-brief", ("sequence_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief))])
                                    self._leafs = OrderedDict()

                                    self.sequence_brief = YList(self)
                                    self._segment_path = lambda: "sequence-briefs"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs, [], name, value)


                                class SequenceBrief(Entity):
                                    """
                                    Detail ACL information
                                    
                                    .. attribute:: sequence_number  (key)
                                    
                                    	Brief ACL information for a particular sequence
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: common_acl
                                    
                                    	Common ACL information across Slices
                                    	**type**\: list of  		 :py:class:`CommonAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl>`
                                    
                                    .. attribute:: interface_acl
                                    
                                    	Interface ACL information across Slices
                                    	**type**\: list of  		 :py:class:`InterfaceAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief, self).__init__()

                                        self.yang_name = "sequence-brief"
                                        self.yang_parent_name = "sequence-briefs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['sequence_number']
                                        self._child_classes = OrderedDict([("common-acl", ("common_acl", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl)), ("interface-acl", ("interface_acl", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl))])
                                        self._leafs = OrderedDict([
                                            ('sequence_number', YLeaf(YType.int32, 'sequence-number')),
                                        ])
                                        self.sequence_number = None

                                        self.common_acl = YList(self)
                                        self.interface_acl = YList(self)
                                        self._segment_path = lambda: "sequence-brief" + "[sequence-number='" + str(self.sequence_number) + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief, ['sequence_number'], name, value)


                                    class CommonAcl(Entity):
                                        """
                                        Common ACL information across Slices
                                        
                                        .. attribute:: next_hop_address
                                        
                                        	Next hop address
                                        	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress>`
                                        
                                        .. attribute:: grant
                                        
                                        	Either permit or deny
                                        	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                        
                                        .. attribute:: logging_enabled
                                        
                                        	Logging enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: per_ace_icmp_enabled
                                        
                                        	Per ACE ICMP enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: next_hop_enabled
                                        
                                        	Next hop enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: default_next_hop_enabled
                                        
                                        	Default next hop enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: total_tcam_entries
                                        
                                        	Number of TCAM entries
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: hits
                                        
                                        	Number of TCAM hits
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: npu_id
                                        
                                        	NPU Id
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl, self).__init__()

                                            self.yang_name = "common-acl"
                                            self.yang_parent_name = "sequence-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress))])
                                            self._leafs = OrderedDict([
                                                ('grant', YLeaf(YType.enumeration, 'grant')),
                                                ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                ('hits', YLeaf(YType.uint64, 'hits')),
                                                ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                            ])
                                            self.grant = None
                                            self.logging_enabled = None
                                            self.per_ace_icmp_enabled = None
                                            self.next_hop_enabled = None
                                            self.default_next_hop_enabled = None
                                            self.total_tcam_entries = None
                                            self.hits = None
                                            self.npu_id = None

                                            self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                            self._segment_path = lambda: "common-acl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                        class NextHopAddress(Entity):
                                            """
                                            Next hop address
                                            
                                            .. attribute:: address_type
                                            
                                            	AddressType
                                            	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress, self).__init__()

                                                self.yang_name = "next-hop-address"
                                                self.yang_parent_name = "common-acl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                ])
                                                self.address_type = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "next-hop-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                    class InterfaceAcl(Entity):
                                        """
                                        Interface ACL information across Slices
                                        
                                        .. attribute:: next_hop_address
                                        
                                        	Next hop address
                                        	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress>`
                                        
                                        .. attribute:: grant
                                        
                                        	Either permit or deny
                                        	**type**\:  :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                        
                                        .. attribute:: logging_enabled
                                        
                                        	Logging enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: per_ace_icmp_enabled
                                        
                                        	Per ACE ICMP enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: next_hop_enabled
                                        
                                        	Next hop enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: default_next_hop_enabled
                                        
                                        	Default next hop enabled/disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: total_tcam_entries
                                        
                                        	Number of TCAM entries
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: hits
                                        
                                        	Number of TCAM hits
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: npu_id
                                        
                                        	NPU Id
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl, self).__init__()

                                            self.yang_name = "interface-acl"
                                            self.yang_parent_name = "sequence-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress))])
                                            self._leafs = OrderedDict([
                                                ('grant', YLeaf(YType.enumeration, 'grant')),
                                                ('logging_enabled', YLeaf(YType.boolean, 'logging-enabled')),
                                                ('per_ace_icmp_enabled', YLeaf(YType.boolean, 'per-ace-icmp-enabled')),
                                                ('next_hop_enabled', YLeaf(YType.boolean, 'next-hop-enabled')),
                                                ('default_next_hop_enabled', YLeaf(YType.boolean, 'default-next-hop-enabled')),
                                                ('total_tcam_entries', YLeaf(YType.uint32, 'total-tcam-entries')),
                                                ('hits', YLeaf(YType.uint64, 'hits')),
                                                ('npu_id', YLeaf(YType.uint8, 'npu-id')),
                                            ])
                                            self.grant = None
                                            self.logging_enabled = None
                                            self.per_ace_icmp_enabled = None
                                            self.next_hop_enabled = None
                                            self.default_next_hop_enabled = None
                                            self.total_tcam_entries = None
                                            self.hits = None
                                            self.npu_id = None

                                            self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                            self._segment_path = lambda: "interface-acl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl, ['grant', 'logging_enabled', 'per_ace_icmp_enabled', 'next_hop_enabled', 'default_next_hop_enabled', 'total_tcam_entries', 'hits', 'npu_id'], name, value)


                                        class NextHopAddress(Entity):
                                            """
                                            Next hop address
                                            
                                            .. attribute:: address_type
                                            
                                            	AddressType
                                            	**type**\:  :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress, self).__init__()

                                                self.yang_name = "next-hop-address"
                                                self.yang_parent_name = "interface-acl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('address_type', YLeaf(YType.enumeration, 'address-type')),
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('ipv6_address', YLeaf(YType.str, 'ipv6-address')),
                                                ])
                                                self.address_type = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "next-hop-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)

    def clone_ptr(self):
        self._top_entity = AccessListHardware()
        return self._top_entity

